@@ -23,6 +23,7 @@
 #include "TCPBuddy.h"
 
 #include <account/xp/AccountEvent.h>
+#include <session/xp/AbiCollab.h>
 #include <session/xp/AbiCollabSessionManager.h>
 
 TCPAccountHandler::TCPAccountHandler()
@@ -188,6 +189,9 @@ bool TCPAccountHandler::disconnect()
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_val_if_fail(pManager, false);
 	
+	// we are disconnected now, no need to receive events anymore
+	pManager->unregisterEventListener(this);
+
 	_teardownAndDestroyHandler();
 	m_bConnected = false;
 
@@ -195,8 +199,7 @@ bool TCPAccountHandler::disconnect()
 	AccountOfflineEvent event;
 	// TODO: fill the event
 	AbiCollabSessionManager::getManager()->signal(event);
-	// we are disconnected now, no need to sent out messages (such as events) anymore
-	pManager->unregisterEventListener(this);	
+
 	return true;
 }
 
@@ -279,6 +282,32 @@ void TCPAccountHandler::_handleAccept(IOServerHandler* pHandler, boost::shared_p
 	pHandler->asyncAccept();	
 }
 
+void TCPAccountHandler::addBuddy(BuddyPtr pBuddy)
+{
+	UT_DEBUGMSG(("TCPAccountHandler::addBuddy()\n"));
+	UT_return_if_fail(pBuddy);
+	
+	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
+	UT_return_if_fail(pManager);
+	
+	if (getProperty("allow-all") == "true")
+	{
+		const UT_GenericVector<AbiCollab *> pSessions = pManager->getSessions();
+		for (UT_sint32 i = 0; i < pSessions.size(); i++)
+		{
+			AbiCollab* pSession = pSessions.getNthItem(i);
+			UT_continue_if_fail(pSession);
+			
+			if (pSession->getAclAccount() != this)
+				continue;
+			
+			pSession->appendAcl(pBuddy->getDescriptor(false).utf8_str());
+		}
+	}
+	
+	AccountHandler::addBuddy(pBuddy);
+}
+
 BuddyPtr TCPAccountHandler::constructBuddy(const PropertyMap& props)
 {
 	UT_DEBUGMSG(("TCPAccountHandler::constructBuddy()\n"));
@@ -324,6 +353,11 @@ void TCPAccountHandler::forceDisconnectBuddy(BuddyPtr buddy)
 	(*it).second->disconnect();
 }
 
+bool TCPAccountHandler::defaultShareState(BuddyPtr /*pBuddy*/)
+{
+	return getProperty("allow-all") == "true";
+}
+
 bool TCPAccountHandler::recognizeBuddyIdentifier(const std::string& /*identifier*/)
 {
 	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
