@@ -32,6 +32,7 @@
 #include "fv_View.h"
 #include "xav_View.h"
 #include "pd_Document.h"
+#include "pd_DocumentRDF.h"
 #include "ut_assert.h"
 #include "ie_types.h"
 #include "ut_misc.h"
@@ -63,6 +64,7 @@
 #include <dialogs/xp/ap_Dialog_CollaborationJoin.h>
 #include <dialogs/xp/ap_Dialog_CollaborationAccounts.h>
 #include <dialogs/xp/ap_Dialog_CollaborationAddAccount.h>
+#include <dialogs/xp/ap_Dialog_CollaborationEditAccount.h>
 #include <dialogs/xp/ap_Dialog_CollaborationAddBuddy.h>
 
 // packet includes
@@ -73,7 +75,7 @@
 
 // account handler includes
 #ifdef ABICOLLAB_HANDLER_TELEPATHY
-#include <backends/telepathy/unix/DTubeUnixAccountHandler.h>
+#include <backends/telepathy/unix/TelepathyUnixAccountHandler.h>
 #endif
 #ifdef ABICOLLAB_HANDLER_XMPP
 #include <backends/xmpp/xp/XMPPAccountHandler.h>
@@ -89,6 +91,9 @@
 #include <backends/service/xp/ServiceAccountHandler.h>
 #include <backends/service/xp/tls_tunnel.h>
 #endif
+#ifdef ABICOLLAB_HANDLER_SIPSIMPLE
+#include <backends/sipsimple/unix/SIPSimpleUnixAccountHandler.h>
+#endif
 
 // event includes
 #include <account/xp/Event.h>
@@ -204,7 +209,7 @@ UT_Error AbiCollabSessionManager::deserializeDocument(PD_Document** pDoc, const
 			DELETEP(imp);
 			g_object_unref(G_OBJECT(gzabwBuf));
 			res = UT_OK;
-		}
+        }
 		else
 			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		g_object_unref(G_OBJECT(source));
@@ -220,6 +225,7 @@ AbiCollabSessionManager::AbiCollabSessionManager(void)
 	m_iDialogJoin(0),
 	m_iDialogAccounts(0),
 	m_iDialogAddAccount(0),
+	m_iDialogEditAccount(0),
 	m_iDialogAddBuddy(0)
 {
 	m_pManager = this;
@@ -240,6 +246,7 @@ bool AbiCollabSessionManager::registerDialogs(void)
 	m_iDialogJoin = pFactory->registerDialog(ap_Dialog_CollaborationJoin_Constructor, XAP_DLGT_NON_PERSISTENT);
 	m_iDialogAccounts = pFactory->registerDialog(ap_Dialog_CollaborationAccounts_Constructor, XAP_DLGT_NON_PERSISTENT);
 	m_iDialogAddAccount = pFactory->registerDialog(ap_Dialog_CollaborationAddAccount_Constructor, XAP_DLGT_NON_PERSISTENT);
+	m_iDialogEditAccount = pFactory->registerDialog(ap_Dialog_CollaborationEditAccount_Constructor, XAP_DLGT_NON_PERSISTENT);
 	m_iDialogAddBuddy = pFactory->registerDialog(ap_Dialog_CollaborationAddBuddy_Constructor, XAP_DLGT_NON_PERSISTENT);	
 	return true;
 }
@@ -249,13 +256,11 @@ bool AbiCollabSessionManager::registerAccountHandlers()
 	UT_DEBUGMSG(("AbiCollabSessionManager::registerAccountHandlers()\n"));
 
 #ifdef ABICOLLAB_HANDLER_TELEPATHY
-	// we don't want to register a d-bus tube account handler here so
-	// swe can construct multiple sugar account handlers later: the 
-	// d-bus tube account handler is a singleton, that should always
-	// be active if it is compiled in
 	UT_DEBUGMSG(("Registering the telepathy account handler!\n"));
-	AccountHandler* pDTubeHandler = new DTubeAccountHandler();
-	addAccount(pDTubeHandler);
+	AccountHandler* pTelepathyHandler = new TelepathyAccountHandler();
+	addAccount(pTelepathyHandler);
+	// TODO: check if we really want to auto-connect this account
+	pTelepathyHandler->connect();
 #endif
 #ifdef ABICOLLAB_HANDLER_XMPP
 	m_regAccountHandlers[XMPPAccountHandler::getStaticStorageType()] = XMPPAccountHandlerConstructor;
@@ -278,6 +283,9 @@ bool AbiCollabSessionManager::registerAccountHandlers()
 	IE_Imp_AbiCollabSniffer* pAbiCollabSniffer = new IE_Imp_AbiCollabSniffer();
 	IE_Imp::registerImporter(pAbiCollabSniffer);
 	m_vImpSniffers.push_back(pAbiCollabSniffer);
+#endif
+#ifdef ABICOLLAB_HANDLER_SIPSIMPLE
+	m_regAccountHandlers[SIPSimpleAccountHandler::getStaticStorageType()] = SIPSimpleAccountHandlerConstructor;
 #endif
 	return true;
 }
@@ -311,6 +319,7 @@ bool AbiCollabSessionManager::unregisterDialogs(void)
 	pFactory->unregisterDialog(m_iDialogJoin);
 	pFactory->unregisterDialog(m_iDialogAccounts);
 	pFactory->unregisterDialog(m_iDialogAddAccount);
+	pFactory->unregisterDialog(m_iDialogEditAccount);
 	pFactory->unregisterDialog(m_iDialogAddBuddy);	
 	return true;
 }
