@@ -594,23 +594,23 @@ void GR_GOChartManager::loadEmbedData(UT_sint32 uid)
 
 UT_sint32 GR_GOChartManager::getWidth(G_GNUC_UNUSED UT_sint32 uid)
 {
-    // FIXME write code this draws a square
-    return 5000;
+  GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
+  UT_return_val_if_fail (pGOChartView, 5000);
+  return pGOChartView->getWidth();
 }
 
 
 UT_sint32 GR_GOChartManager::getAscent(G_GNUC_UNUSED UT_sint32 uid)
 {
-  // FIXME write code this draws a square
-  return 5000;
+  GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
+  UT_return_val_if_fail (pGOChartView, 5000);
+  return pGOChartView->getHeight();
 }
 
 
 UT_sint32 GR_GOChartManager::getDescent(G_GNUC_UNUSED UT_sint32 uid)
 {
-  // FIXME write code
- return 0;
-
+  return 0;
 }
 
 void GR_GOChartManager::setColor(G_GNUC_UNUSED UT_sint32 uid, G_GNUC_UNUSED UT_RGBColor c)
@@ -697,7 +697,7 @@ GOChartView::GOChartView(GR_GOChartManager * pGOMan): m_pGOMan(pGOMan)
 	m_Image = NULL;
 	m_Renderer = GOG_RENDERER(g_object_new(GOG_TYPE_RENDERER, NULL));
 	pix_width = pix_height = 0;
-	width = height = 0;
+	width = height = 5000;
 	m_Guru = NULL;
 }
 
@@ -720,6 +720,7 @@ void GOChartView::render(UT_Rect & rec)
 		return;
 	}
 	GR_CairoGraphics *pUGG = static_cast<GR_CairoGraphics*>(m_pGOMan->getGraphics());
+	pUGG->beginPaint();
 	cairo_t *cr = pUGG->getCairo ();
 	UT_sint32 _width = pUGG->tdu(rec.width);
 	UT_sint32 _height = pUGG->tdu(rec.height);
@@ -728,27 +729,28 @@ void GOChartView::render(UT_Rect & rec)
 	UT_sint32 zoom = pUGG->getZoomPercentage ();
 	UT_sint32 real_width = _width * 100 / zoom;
 	UT_sint32 real_height = _height * 100 / zoom;
-	if (real_width != width || real_height != height)
+	if (rec.width != width || rec.height != height)
 	{
-		width = real_width;
-		height = real_height;
-		gog_graph_set_size (m_Graph, width, height);
+		width = rec.width;
+		height = rec.height;
+		gog_graph_set_size (m_Graph, real_width, real_height);
 	}
 	cairo_save (cr);
 	cairo_translate (cr, x, y);
 	gog_renderer_render_to_cairo (m_Renderer, cr, _width, _height);
 	cairo_new_path (cr); // just in case a path has not been ended
 	cairo_restore (cr);
+	pUGG->endPaint();
 }
 
 UT_ByteBuf *GOChartView::exportToPNG ()
 {
 	UT_return_val_if_fail (m_Graph, NULL);
 	UT_ByteBuf *pBuf = new UT_ByteBuf ();
-	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
-										width, height);
+	int w = width * 300 / UT_LAYOUT_RESOLUTION, h = height * 300 / UT_LAYOUT_RESOLUTION;
+	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, w, h);
 	cairo_t *cr = cairo_create (surface);
-	gog_renderer_render_to_cairo (m_Renderer, cr, width, height);
+	gog_renderer_render_to_cairo (m_Renderer, cr, w, h);
 	cairo_destroy (cr);
 	cairo_surface_write_to_png_stream (surface,
 	    reinterpret_cast<cairo_write_func_t>(abi_CairoWrite), pBuf);
@@ -761,7 +763,7 @@ UT_ByteBuf *GOChartView::exportToSVG ()
 	UT_return_val_if_fail (m_Graph, NULL);
 	UT_ByteBuf *pBuf = NULL; /*new UT_ByteBuf ();
 	cairo_surface_t *surface = cairo_svg_surface_create_for_stream (
-										reinterpret_cast<cairo_write_func_t>(UT_ByteBuf::CairoWrite),
+										reinterpret_cast<cairo_write_func_t>(abi_CairoWrite),
 										pBuf, width, height);
 	cairo_t *cr = cairo_create (surface);
 	cairo_surface_destroy (surface);
