@@ -3,6 +3,7 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2000 Hubert Figuire
+ *               2010 Ingo Brueckl
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +25,8 @@
 #define IE_IMP_MSWRITE_H
 
 #include <stdio.h>
+#include <string>
+#include <map>
 
 #include "ut_bytebuf.h"
 #include "ut_string_class.h"
@@ -37,14 +40,10 @@ class PD_Document;
 /* the fonts */
 typedef struct wri_font {
 	short	ffid;
-	char	*name;
+	std::string name;
+	const char *codepage;
 } wri_font;
 
-typedef struct wri_image {
-    unsigned char *png_image;
-    int length;
-} wri_image;
-
 // The importer/reader for MS Write Files.
 
 class IE_Imp_MSWrite_Sniffer : public IE_ImpSniffer
@@ -73,6 +72,12 @@ class IE_Imp_MSWrite : public IE_Imp
 public:
 	IE_Imp_MSWrite(PD_Document * pDocument);
 	~IE_Imp_MSWrite();
+
+	struct doc_range
+	{
+		unsigned int start;
+		unsigned int end;
+	};
 	
 protected:
 	virtual UT_Error    _loadFile(GsfInput * input);
@@ -83,26 +88,33 @@ private:
 	int read_ffntb ();
 	void translate_char (char ch, UT_UCS4String & buf);
 	int read_sep();
-	int read_pap ();
+	int read_pap (int cStart, int cLimit);
 	int read_char (int fcFirst2, int fcLim2);
-#if 0
-	int wri_pict_read (unsigned char *data, int size);
-	int wri_pict_print_data ();
-#endif
+	int read_pic(int, int);
 	
 	GsfInput* mFile;
 	
 	UT_uint32 wri_fonts_count;
 	struct wri_font *wri_fonts;
-	struct wri_image **wri_images;
-	UT_uint32 wri_images_count;
+	UT_uint32 pic_nr;
 	
 	struct wri_struct *write_file_header;
 	struct wri_struct *write_picture;
+	struct wri_struct *write_ole_picture;
+
+	doc_range m_header, m_footer;
+
+	std::string default_cp;
+	const char *get_codepage(char *facename, char **newname=NULL) const; // gets cp by font name;
+	void set_codepage(const char *cp);	// sets the translation table to corresponding codeset
+	void add_subdoc(int type, unsigned int from, unsigned int to);
+	void _append_hdrftr(int type);
+
+	bool m_insubdoc;
 	
 	UT_UCS4String mCharBuf;    // buffer for char runs.
 	UT_ByteBuf mTextBuf;       // complete text buffer as extracted out of the file.
-	UT_UCS4_mbtowc charconv;   // CP1252 to unicode conversion.
+	UT_UCS4_mbtowc charconv;   // unicode conversion.
 	bool lf;
 };
 
