@@ -88,7 +88,7 @@ void ODi_ListLevelStyle::startElement (const gchar* pName,
 	    UT_UTF8String sStyleName = "BaseHeading ";
 	    sStyleName += m_level;
 	    m_textStyleName =  sStyleName;
-	    UT_DEBUGMSG(("Outline List level Style name %s \n",sStyleName.utf8_str()));
+	    xxx_UT_DEBUGMSG(("Outline List level Style name %s \n",sStyleName.utf8_str()));
 	     pVal = UT_getAttribute ("style:num-format", ppAtts);
 	     if(pVal && *pVal)
 	     {
@@ -149,7 +149,7 @@ void ODi_ListLevelStyle::endElement (const gchar* pName,
         !strcmp("text:list-level-style-image", pName)) {
             
         // We're done.
-        UT_DEBUGMSG(("Finished Level %s \n",m_textStyleName.utf8_str()));
+        xxx_UT_DEBUGMSG(("Finished Level %s \n",m_textStyleName.utf8_str()));
         rAction.popState();
     }
 }
@@ -231,7 +231,7 @@ void ODi_ListLevelStyle::getAbiProperties(UT_UTF8String& rProps,
     UT_UTF8String odTextIndent;
 
     // 1. The properties of the style denoted by the paragraph's style:list-style-name
-    if (!pStyle->getListStyleName().empty())
+    if (pStyle != NULL && !pStyle->getListStyleName().empty())
     {
         if (!m_marginLeft.empty())
             odMarginLeft = m_marginLeft;
@@ -492,7 +492,13 @@ ODi_Numbered_ListLevelStyle::ODi_Numbered_ListLevelStyle(ODi_ElementStack& rElem
         
     // It seens that OpenDocument aways uses a dot "." as level delimiter.
     m_abiListListDecimal = ".";
-}
+    //
+    // These are default values for OpenDocument lists
+    //
+    m_abiListListDelim += "%L";
+    m_abiListStartValue = "1";
+    UT_UTF8String_sprintf(m_abiListType, "%d", NUMBERED_LIST);
+ }
 
 
 
@@ -511,7 +517,7 @@ void ODi_Numbered_ListLevelStyle::startElement (const gchar* pName,
     if (!strcmp("text:list-level-style-number", pName) || 
 	!strcmp("text:outline-level-style", pName)) {
         UT_UTF8String prefix, suffix;
-        UT_DEBUGMSG(("Doing a numbered list type %s \n",pName));
+        xxx_UT_DEBUGMSG(("Doing a numbered list type %s \n",pName));
         pVal = UT_getAttribute ("style:num-format", ppAtts);
         UT_ASSERT_HARMLESS(pVal);
         _setAbiListType(pVal);
