@@ -46,6 +46,15 @@
 #include <pd_Document.h>
 #include <pf_Frag_Strux.h>
 
+#include <list>
+
+
+
+
+
+/************************************************************/
+/************************************************************/
+/************************************************************/
 
 /**
  * Constructor
@@ -83,7 +92,8 @@ ODi_TextContent_ListenerState::ODi_TextContent_ListenerState (
 		  m_rAbiData(rAbiData),
 		  m_bPendingTextbox(false),
 		  m_bHeadingList(false),
-		  m_prevLevel(0)
+		  m_prevLevel(0),
+		  m_bContentWritten(false)
 {
     UT_ASSERT_HARMLESS(m_pAbiDocument);
     UT_ASSERT_HARMLESS(m_pStyles);
@@ -162,7 +172,7 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         }
 
     } else if (!strcmp(pName, "text:p" )) {
-        
+
         if (m_bPendingAnnotation) {
             _insertAnnotation();
         }
@@ -182,19 +192,15 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
             // be at level 1.
             pOutlineLevel = "1";
         }
-	UT_UTF8String sHeadingListName = "BaseHeading";
-	m_listLevel = atoi(pOutlineLevel);
-	m_pCurrentListStyle =  m_pStyles->getList( sHeadingListName.utf8_str());
-	if(m_pCurrentListStyle && m_pCurrentListStyle->getLevelStyle(m_listLevel)->isVisible())
-	{
-	     UT_DEBUGMSG(("Found %s ! outline level %s \n",sHeadingListName.utf8_str(),pOutlineLevel));
-	     m_bHeadingList = true;
-	}
-	else
-	{
-	     UT_DEBUGMSG(("Not present or defined as list \n",sHeadingListName.utf8_str()));
+        UT_UTF8String sHeadingListName = "BaseHeading";
+        m_listLevel = atoi(pOutlineLevel);
+        m_pCurrentListStyle =  m_pStyles->getList( sHeadingListName.utf8_str());
+        if(m_pCurrentListStyle && m_pCurrentListStyle->getLevelStyle(m_listLevel)->isVisible())
+        {
+            xxx_UT_DEBUGMSG(("Found %s ! outline level %s \n",sHeadingListName.utf8_str(),pOutlineLevel));
+            m_bHeadingList = true;
+        }
 
-	}
         pStyleName = UT_getAttribute("text:style-name", ppAtts);
         if (pStyleName) 
         {
@@ -261,7 +267,8 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         _flush();
         
         m_pAbiDocument->appendSpan(string.ucs4_str(), string.size());
-        
+	m_bContentWritten = true;
+       
     } else if (!strcmp(pName, "text:tab")) {
         // A tab character.
 
@@ -272,7 +279,8 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         _flush();
         
         m_pAbiDocument->appendSpan(string.ucs4_str(), string.size());
-        
+	m_bContentWritten = true; 
+
     } else if (!strcmp(pName, "text:table-of-content")) {
         
         _flush ();
@@ -327,6 +335,28 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
                 // We just ignore this <text:span>.
             }
         }
+
+    } else if (!strcmp(pName, "text:meta")) {
+        
+        _flush ();
+
+        UT_UTF8String generatedID;
+        const gchar* xmlid = UT_getAttribute("xml:id", ppAtts);
+        if( !xmlid )
+        {
+            generatedID = UT_UTF8String_sprintf("%d", m_pAbiDocument->getUID( UT_UniqueId::Annotation ));
+            xmlid = generatedID.utf8_str();
+        }
+        
+        const gchar* pa[10] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+        pa[0] = PT_XMLID;
+        pa[1] = xmlid;
+        // sanity check
+        pa[2] = "this-is-an-rdf-anchor";
+        pa[3] = "yes";
+        
+        m_pAbiDocument->appendObject( PTO_RDFAnchor, pa );
+        xmlidStackForTextMeta.push_back( xmlid );
         
     } else if (!strcmp(pName, "text:line-break")) {
         
@@ -346,9 +376,10 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         
         _flush ();
         const gchar * pAttr = UT_getAttribute ("text:name", ppAtts);
+        const gchar* xmlid = UT_getAttribute("xml:id", ppAtts);
 
         if(pAttr) {
-            _insertBookmark (pAttr, "start");
+            _insertBookmark (pAttr, "start", xmlid );
             _insertBookmark (pAttr, "end");
         } else {
             UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
@@ -358,9 +389,11 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
 
         _flush ();
         const gchar * pAttr = UT_getAttribute ("text:name", ppAtts);
-
+        const gchar* xmlid = UT_getAttribute("xml:id", ppAtts);
+        xmlidMapForBookmarks[pAttr] = ( xmlid ? xmlid : "" );
+        
         if(pAttr) {
-            _insertBookmark (pAttr, "start");
+            _insertBookmark (pAttr, "start", xmlid );
         } else {
             UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         }
@@ -369,9 +402,21 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
 
         _flush ();
         const gchar * pAttr = UT_getAttribute ("text:name", ppAtts);
+        std::string xmlid = "";
+        
 
+        if( const gchar* t = UT_getAttribute("xml:id", ppAtts))
+        {
+            xmlid = t;
+        }
+        else
+        {
+            xmlid = xmlidMapForBookmarks[pAttr];
+        }
+        xmlidMapForBookmarks.erase(pAttr);
+        
         if(pAttr) {
-            _insertBookmark (pAttr, "end");
+            _insertBookmark (pAttr, "end", xmlid.c_str() );
         } else {
             UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
         }
@@ -867,6 +912,25 @@ void ODi_TextContent_ListenerState::endElement (const gchar* pName,
         _flush ();
         _popInlineFmt();
         m_pAbiDocument->appendFmt(&m_vecInlineFmt);
+
+    } else if (!strcmp(pName, "text:meta")) {
+        
+        _flush ();
+
+        std::string xmlid = xmlidStackForTextMeta.back();
+        xmlidStackForTextMeta.pop_back();
+        
+        const gchar* ppAtts[10] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+        ppAtts[0] = PT_XMLID;
+        ppAtts[1] = xmlid.c_str();
+        // sanity check
+        ppAtts[2] = "this-is-an-rdf-anchor";
+        ppAtts[3] = "yes";
+        ppAtts[4] = PT_RDF_END;
+        ppAtts[5] = "yes";
+        
+        m_pAbiDocument->appendObject( PTO_RDFAnchor, ppAtts );
+        
         
     } else if (!strcmp(pName, "text:a")) {
         
@@ -1045,16 +1109,53 @@ void ODi_TextContent_ListenerState::endElement (const gchar* pName,
 void ODi_TextContent_ListenerState::charData (
                             const gchar* pBuffer, int length)
 {
-    if (pBuffer && length) {
-        if (m_bAcceptingText) {
-            m_charData += UT_UCS4String (pBuffer, length, true);
+    if (!pBuffer || !length)
+        return; // nothing to do
 
-        } else if (m_bPendingAnnotationAuthor) {
-            m_sAnnotationAuthor = pBuffer;
-
-        } else if (m_bPendingAnnotationDate) {
-            m_sAnnotationDate = pBuffer;
+    if (m_bAcceptingText) 
+    {
+        if(!m_bContentWritten)
+        {
+            // Strip all leading space if immediately after a paragragh
+            // column or page break
+            UT_UCS4String sUCS = UT_UCS4String (pBuffer, length, false);
+            UT_UCS4Char ucs = sUCS[0];
+            UT_uint32 i = 0;
+            while(ucs != 0 && UT_UCS4_isspace(ucs) && (i<sUCS.size()))
+            {
+                i++;
+                ucs = sUCS[i];
+            }
+            //
+            // Leave a single trailing space if one or more exists
+            //
+            UT_uint32 j = sUCS.size()-1;
+            ucs = sUCS[j];
+            while(UT_UCS4_isspace(ucs) && (j>i))
+            {
+                j--;
+                ucs = sUCS[j];
+            }
+            for(i=i; i<=j ; i++)
+            {
+                m_charData += sUCS[i];
+            }
+            if(j<sUCS.size()-1)
+               m_charData += UCS_SPACE;
         }
+        else
+        {
+            printf(">>> content written!\n");
+            m_charData += UT_UCS4String (pBuffer, length, true);
+        }
+    } 
+    else if (m_bPendingAnnotationAuthor) 
+    {
+        m_sAnnotationAuthor = pBuffer;
+    } 
+    else if (m_bPendingAnnotationDate) 
+    {
+        m_sAnnotationDate = pBuffer;
     }
 }
 
@@ -1063,16 +1164,23 @@ void ODi_TextContent_ListenerState::charData (
  * 
  */
 void ODi_TextContent_ListenerState::_insertBookmark (const gchar* pName,
-                                             const gchar* pType)
+                                                     const gchar* pType,
+                                                     const gchar* xmlid )
 {
     UT_return_if_fail(pName && pType);
 
-    const gchar* pPropsArray[5];
-    pPropsArray[0] = (gchar *)"name";
-    pPropsArray[1] = pName;
-    pPropsArray[2] = (gchar *)"type";
-    pPropsArray[3] = pType;
-    pPropsArray[4] = 0;
+    int idx = 0;
+    const gchar* pPropsArray[10];
+    pPropsArray[idx++] = (gchar *)"name";
+    pPropsArray[idx++] = pName;
+    pPropsArray[idx++] = (gchar *)"type";
+    pPropsArray[idx++] = pType;
+    if( xmlid && strlen(xmlid) )
+    {
+        pPropsArray[idx++] = PT_XMLID;
+        pPropsArray[idx++] = xmlid;
+    }
+    pPropsArray[idx++] = 0;
     m_pAbiDocument->appendObject (PTO_Bookmark, pPropsArray);
 }
 
@@ -1085,6 +1193,7 @@ void ODi_TextContent_ListenerState::_flush ()
     if (m_charData.size () > 0 && m_bAcceptingText) {
         m_pAbiDocument->appendSpan (m_charData.ucs4_str(), m_charData.size ());
         m_charData.clear ();
+	m_bContentWritten = true;
     } 
 }
 
@@ -1421,7 +1530,10 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
         bool ok;
         UT_UTF8String props;
         const ODi_Style_Style* pStyle;
-        
+        m_bContentWritten = false;
+        const gchar* xmlid = 0;
+
+        xmlid = UT_getAttribute ("xml:id", ppParagraphAtts);
         
         if (!strcmp(m_rElementStack.getStartTag(0)->getName(), "text:list-item")) {
             // That's a list paragraph.
@@ -1429,7 +1541,6 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
         }
 
         pStyleName = UT_getAttribute ("text:style-name", ppParagraphAtts);
-
         if (pStyleName) {
             pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
 
@@ -1464,6 +1575,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
                     m_pAbiDocument->appendStrux(PTX_Block, NULL);
                     m_pAbiDocument->appendSpan (&ucs, 1);
                     m_bOpenedBlock = true;
+                    m_bContentWritten = false;
                 }
             } else {
                 _insureInSection();
@@ -1477,22 +1589,21 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
                         m_pAbiDocument->appendStrux(PTX_Block, NULL);
                         m_pAbiDocument->appendSpan (&ucs, 1);
                         m_bOpenedBlock = true;
+                        m_bContentWritten = false;
                     } else if (pStyle->getBreakBefore() == "column") {
                         ucs = UCS_VTAB;
                         // Append an empty paragraph with this one char
                         m_pAbiDocument->appendStrux(PTX_Block, NULL);
                         m_pAbiDocument->appendSpan (&ucs, 1);
                         m_bOpenedBlock = true;
+                        m_bContentWritten = false;
                     }
                 }
             }
 
         }
         
-
-
         i = 0;
-
         if (bIsListParagraph && !m_alreadyDefinedAbiParagraphForList) {
             ODi_ListLevelStyle* pListLevelStyle = NULL;
             
@@ -1506,12 +1617,12 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
             ppAtts[i++] = "level";
             ppAtts[i++] = listLevel;
             if (pListLevelStyle && pListLevelStyle->getAbiListID() && pListLevelStyle->getAbiListParentID())
-	    {
-	        if(m_listLevel < m_prevLevel)
-		{
-		     m_pCurrentListStyle->redefine( m_pAbiDocument,m_prevLevel);
-		}
-		m_prevLevel = m_listLevel;
+	        {
+	            if(m_listLevel < m_prevLevel)
+		        {
+		            m_pCurrentListStyle->redefine( m_pAbiDocument,m_prevLevel);
+		        }
+                m_prevLevel = m_listLevel;
 		
                 ppAtts[i++] = "listid";
                 ppAtts[i++] = pListLevelStyle->getAbiListID()->utf8_str();
@@ -1520,7 +1631,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
                 // the <l> tag.
                 ppAtts[i++] = "parentid";
                 ppAtts[i++] = pListLevelStyle->getAbiListParentID()->utf8_str();
-		UT_DEBUGMSG(("Level |%s| Listid |%s| Parentid |%s| \n",ppAtts[i-5],ppAtts[i-3],ppAtts[i-1]));
+                xxx_UT_DEBUGMSG(("Level |%s| Listid |%s| Parentid |%s| \n",ppAtts[i-5],ppAtts[i-3],ppAtts[i-1]));
             }
             
             if (pStyle!=NULL) {
@@ -1549,13 +1660,12 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
             UT_ASSERT(ok);
             m_bOpenedBlock = true;
 
-            
-
             ppAtts[0] = "type";
             ppAtts[1] = "list_label";
             ppAtts[2] = 0;
             ok = m_pAbiDocument->appendObject(PTO_Field, ppAtts);
             UT_ASSERT(ok);
+            m_bContentWritten = true;
             
             // Inserts a tab character. AbiWord seems to need it in order to
             // implement the space between the list mark (number/bullet) and
@@ -1571,7 +1681,8 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
             
             UT_UCSChar ucs = UCS_LF;
             m_pAbiDocument->appendSpan(&ucs,1);
-            
+               m_bContentWritten = true;
+
             if (pStyle!=NULL) { 
                 if (pStyle->isAutomatic()) {
                     // Automatic styles are not defined on the document, so, we
@@ -1610,7 +1721,13 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
                     ppAtts[i++] = pStyle->getDisplayName().utf8_str();
                 }
             }
-        
+
+            if( xmlid )
+            {
+                ppAtts[i++] = PT_XMLID;
+                ppAtts[i++] = xmlid;
+            }
+            
             ppAtts[i] = 0; // Marks the end of the attributes list.
             m_pAbiDocument->appendStrux(PTX_Block, (const gchar**)ppAtts);
             m_bOpenedBlock = true;
@@ -1649,7 +1766,13 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
             ppAtts[4] = 0;
             
             ok = m_pAbiDocument->appendObject(PTO_Field, ppAtts);
-            UT_ASSERT(ok);           
+	        //
+	        // Now insert the tab after the anchor
+	        //
+	        UT_UCSChar ucs = UCS_TAB;
+	        m_pAbiDocument->appendSpan (&ucs, 1);
+	        m_bContentWritten = true;
+                UT_ASSERT(ok);           
         }
 }
 
@@ -1664,7 +1787,7 @@ void ODi_TextContent_ListenerState::_endParagraphElement (
                                             
     const gchar* pStyleName;
     const ODi_Style_Style* pStyle;
-    
+
     _flush ();
     m_bAcceptingText = false;
     
@@ -1757,11 +1880,13 @@ void ODi_TextContent_ListenerState::_flushPendingParagraphBreak() {
             UT_UCSChar ucs = UCS_FF;
             m_pAbiDocument->appendSpan (&ucs, 1);
             m_bOpenedBlock = true;
+            m_bContentWritten = false;
         } else if (m_pendingParagraphBreak == "column") {
             m_pAbiDocument->appendStrux(PTX_Block, NULL);
             UT_UCSChar ucs = UCS_VTAB;
             m_pAbiDocument->appendSpan (&ucs, 1);
             m_bOpenedBlock = true;
+            m_bContentWritten = false;
         }
         
         m_pendingParagraphBreak.clear();
