@@ -54,6 +54,7 @@
 #include "pt_PieceTable.h"
 #include "ap_Win32Toolbar_FontCombo.h"
 #include "ap_Win32App.h"
+#include "ut_Win32LocaleString.h"
 
 
 #ifndef TBSTYLE_EX_DRAWDDARROWS
@@ -203,12 +204,14 @@ bool EV_Win32Toolbar::toolbarEvent(XAP_Toolbar_Id id,
 
 		const EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
 
-		if (!pAction) return true;
+		if (!pAction) 
+            return true;
 
 		AV_View * pView = m_pWin32Frame->getCurrentView();
 		
 		const char * szMethodName = pAction->getMethodName();
-		if (!szMethodName) return true;
+		if (!szMethodName) 
+            return true;
 		
 		const EV_EditMethodContainer * pEMC = m_pWin32App->getEditMethodContainer();
 		EV_EditMethod * pEM = pEMC->findEditMethodByName(szMethodName);
@@ -272,7 +275,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ToolBarWndProc (HWND hWnd, UINT uMessage, WPA
 		return (LRESULT) GetSysColorBrush (COLOR_WINDOW);
 	}
 	
-	return (CallWindowProc(s_lpfnDefToolBar, hWnd, uMessage, wParam, lParam));
+	return (CallWindowProcW(s_lpfnDefToolBar, hWnd, uMessage, wParam, lParam));
 }
 
 LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM lParam)
@@ -282,7 +285,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 		/* Draws the font preview in the font selection combobox*/
 		case WM_DRAWITEM:
 		{						
-			EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLong(hWnd, GWL_USERDATA);			
+			EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLongPtrW(hWnd, GWLP_USERDATA);			
 			UINT u = GetDlgCtrlID(hWnd);
 			XAP_Toolbar_Id id = t->ItemIdFromWmCommand(u);
 						
@@ -308,17 +311,18 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 			}
 
 			HFONT hFont, hUIFont;
-			LOGFONT logfont;
+			LOGFONTW logfont;
 			SIZE size;
 			HFONT hfontSave;
+            UT_Win32LocaleString str;
 			const UT_GenericVector<const char*> * v = t->m_pFontCtrl->getContents();
-			const char * sz  = (const char *)v->getNthItem(dis->itemData);			
-			
+			str.fromUTF8 (v->getNthItem(dis->itemData));
+
 			if(dis->itemState & ODS_COMBOBOXEDIT)
 			{
 				HFONT hUIFont = (HFONT) GetStockObject(DEFAULT_GUI_FONT);
 				hfontSave = (HFONT) SelectObject (dis->hDC, hUIFont);
-				ExtTextOut(dis->hDC, dis->rcItem.left, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, sz, lstrlen(sz), 0);
+				ExtTextOutW(dis->hDC, dis->rcItem.left, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, str.c_str(), str.size(), 0);
 				SelectObject (dis->hDC, hfontSave);				
 			}
 			else
@@ -338,9 +342,9 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 				logfont.lfOutPrecision = OUT_DEFAULT_PRECIS;
 				logfont.lfClipPrecision = CLIP_DEFAULT_PRECIS;
 				logfont.lfQuality = DEFAULT_QUALITY;
-				logfont.lfPitchAndFamily = DEFAULT_PITCH | FF_DONTCARE;			  
-				strcpy (logfont.lfFaceName, sz);   
-				hFont = CreateFontIndirect (&logfont);			
+				logfont.lfPitchAndFamily = DEFAULT_PITCH | FF_DONTCARE;
+				lstrcpynW(logfont.lfFaceName, str.c_str(), LF_FACESIZE);
+				hFont = CreateFontIndirectW (&logfont);			
 
 				if(dis->itemState & ODS_SELECTED) /* HighLight the selected text*/
 				{
@@ -359,13 +363,13 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 
 				/*Fontname in regular font*/
 				hfontSave = (HFONT) SelectObject (dis->hDC, hUIFont);
-				ExtTextOut(dis->hDC, dis->rcItem.left, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, sz, lstrlen(sz), 0);
+                ExtTextOutW(dis->hDC, dis->rcItem.left, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, str.c_str(), str.size(), 0);
 				
 				/*Font example after the name*/
-				const char* szSample="AbCdEfGhIj";
-				GetTextExtentPoint32(dis->hDC, sz, lstrlen(sz), &size);
+				wchar_t* szSample = L"AbCdEfGhIj";
+                GetTextExtentPoint32W(dis->hDC, str.c_str(), str.size(), &size);
 				SelectObject (dis->hDC, hFont);
-				ExtTextOut(dis->hDC, dis->rcItem.left+size.cx+5, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, szSample, lstrlen(szSample), 0);					
+				ExtTextOutW(dis->hDC, dis->rcItem.left+size.cx+5, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, szSample, wcslen(szSample), 0);
 				SelectObject (dis->hDC, hfontSave);									
 				DeleteObject(hFont); 
 			}
@@ -389,8 +393,8 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 
 			HWND hwndToolbar = GetParent(hWnd);
 
-			hWndTT = (HWND)SendMessage(hwndToolbar, TB_GETTOOLTIPS, 0,0);
-			SendMessage(hWndTT, TTM_RELAYEVENT, 0, (LPARAM)(LPMSG)&msg);
+			hWndTT = (HWND)SendMessageW(hwndToolbar, TB_GETTOOLTIPS, 0,0);
+			SendMessageW(hWndTT, TTM_RELAYEVENT, 0, (LPARAM)(LPMSG)&msg);
 			break;
 		}
 
@@ -400,19 +404,21 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 			{								
 				case CBN_SELCHANGE:
 				{
-					UT_sint32 iSelected = SendMessage(hWnd, CB_GETCURSEL, 0, 0);
+					UT_sint32 iSelected = SendMessageW(hWnd, CB_GETCURSEL, 0, 0);
 									
 					if(iSelected != -1)
 					{							
 						static UT_UCSChar ucs_buf[COMBO_BUF_LEN];
-						UT_uint32 bufLength = SendMessage(hWnd, CB_GETLBTEXTLEN, iSelected, (LPARAM)0) + 1;
-						char* buf = (char*)g_try_malloc(bufLength);
-						UT_uint32 dataLength = SendMessage(hWnd, CB_GETLBTEXT, iSelected, (LPARAM)buf);
+                        UT_Win32LocaleString str;
+						UT_uint32 bufLength = SendMessageW(hWnd, CB_GETLBTEXTLEN, iSelected, (LPARAM)0) + 1;
+						wchar_t* buf = (wchar_t*)g_try_malloc(bufLength * sizeof (wchar_t));
+						UT_uint32 dataLength = SendMessageW(hWnd, CB_GETLBTEXT, iSelected, (LPARAM)buf);
+                        str.fromLocale (buf);
 
-						UT_UCS4_strncpy_char(ucs_buf, buf, COMBO_BUF_LEN-1);
+                        UT_UCS4_strcpy_utf8_char(ucs_buf, str.utf8_str().utf8_str());
 						UT_UCSChar * pData = (UT_UCSChar *) ucs_buf;	// HACK: should be void *
 
-						EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLong(hWnd, GWL_USERDATA);
+						EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLongPtrW(hWnd, GWLP_USERDATA);
 						UT_ASSERT(t);
 
 						if(dataLength)
@@ -426,7 +432,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 								UT_sint32 iSelected;					
 								int nData;
 								
-								iSelected = SendMessage(hWnd, CB_GETCURSEL, 0, 0);										
+								iSelected = SendMessageW(hWnd, CB_GETCURSEL, 0, 0);										
 
 								// Find the proper non-localised text                                                                             					
 								XAP_Toolbar_ControlFactory * pFactory = t->m_pWin32App->getControlFactory();
@@ -434,9 +440,11 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 								AP_Win32Toolbar_StyleCombo * pStyleC = static_cast<AP_Win32Toolbar_StyleCombo *>(pControl);
 								pStyleC->repopulate();                                                                                                
 
-								nData  = SendMessage(hWnd, CB_GETITEMDATA, iSelected, 0);								
+								nData  = SendMessageW(hWnd, CB_GETITEMDATA, iSelected, 0);								
 
-								UT_UCS4_strncpy_char(ucs_buf, t->m_vecOrgStylesNames.getNthItem(nData)->utf8_str(), COMBO_BUF_LEN-1);	
+								UT_UTF8String *utf = t->m_vecOrgStylesNames.getNthItem(nData);
+								UT_ASSERT((utf && (utf->length() < (COMBO_BUF_LEN-1))));
+								UT_UCS4_strcpy_utf8_char(ucs_buf, utf->utf8_str());	
 								dataLength = UT_UCS4_strlen (ucs_buf);
 
 								DELETEP(pControl);
@@ -449,7 +457,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 					}	
 					else
 					{
-						PostMessage(hWnd, WM_KEYDOWN, VK_ESCAPE, 0);
+						PostMessageW(hWnd, WM_KEYDOWN, VK_ESCAPE, 0);
 					}
 						
 					break;
@@ -463,7 +471,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 			
 		case WM_KEYDOWN:
 		{
-			EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLong(hWnd, GWL_USERDATA);
+			EV_Win32Toolbar * t = (EV_Win32Toolbar *) GetWindowLongPtrW(hWnd, GWLP_USERDATA);
 			UT_ASSERT(t);
 
 			switch (wParam)
@@ -487,7 +495,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 			}
 		}
 	}
-	return (CallWindowProc(s_lpfnDefCombo, hWnd, uMessage, wParam, lParam));
+	return (CallWindowProcW(s_lpfnDefCombo, hWnd, uMessage, wParam, lParam));
 }
 
 
@@ -538,9 +546,9 @@ bool EV_Win32Toolbar::synthesize(void)
 
 	// NOTE: this toolbar will get placed later, by frame or rebar
 
-	m_hwnd = UT_CreateWindowEx(0, 
-							   TOOLBARCLASSNAME, // window class name
-							   (LPSTR) NULL,			// window caption
+	m_hwnd = UT_CreateWindowEx(0,                              
+							   TOOLBARCLASSNAMEW, // window class name
+							   NULL,			// window caption
 							   WS_CHILD | WS_VISIBLE 
 							   | WS_CLIPCHILDREN | WS_CLIPSIBLINGS 
 							   | TBSTYLE_TOOLTIPS | TBSTYLE_FLAT
@@ -562,12 +570,12 @@ bool EV_Win32Toolbar::synthesize(void)
 	UT_ASSERT(m_hwnd);
 
 	// override the window procedure 		
-	s_lpfnDefToolBar = (WHICHPROC)GetWindowLong(m_hwnd, GWL_WNDPROC);
-	SetWindowLong(m_hwnd, GWL_WNDPROC, (LONG)_ToolBarWndProc);
-	SetWindowLong(m_hwnd, GWL_USERDATA, (LONG)this);
+	s_lpfnDefToolBar = (WHICHPROC)GetWindowLongPtrW(m_hwnd, GWLP_WNDPROC);
+	SetWindowLongPtrW(m_hwnd, GWLP_WNDPROC, (LONG_PTR)_ToolBarWndProc);
+	SetWindowLongPtrW(m_hwnd, GWLP_USERDATA, (LONG_PTR)this);
 
 
-	SendMessage(m_hwnd, TB_BUTTONSTRUCTSIZE, (WPARAM) sizeof(TBBUTTON), 0);  
+	SendMessageW(m_hwnd, TB_BUTTONSTRUCTSIZE, (WPARAM) sizeof(TBBUTTON), 0);  
 
 	// the Windows Common Control Toolbar requires that we set
 	// a bitmap size in the toolbar window **before** we actually
@@ -583,10 +591,10 @@ bool EV_Win32Toolbar::synthesize(void)
 	const WORD MY_MAXIMUM_BITMAP_Y = 24;
 
 	if( bIcons )
-		SendMessage(m_hwnd, TB_SETBITMAPSIZE, 0,
+		SendMessageW(m_hwnd, TB_SETBITMAPSIZE, 0,
 					(LPARAM) MAKELONG(MY_MAXIMUM_BITMAP_X,MY_MAXIMUM_BITMAP_Y));
 	else
-		SendMessage(m_hwnd, TB_SETBITMAPSIZE, 0, (LPARAM) MAKELONG(0,0));
+		SendMessageW(m_hwnd, TB_SETBITMAPSIZE, 0, (LPARAM) MAKELONG(0,0));
 
 	DWORD dwColor = GetSysColor(COLOR_BTNFACE);
 	UT_RGBColor backgroundColor(GetRValue(dwColor),GetGValue(dwColor),GetBValue(dwColor));
@@ -681,8 +689,8 @@ bool EV_Win32Toolbar::synthesize(void)
 							dwStyle |= CBS_OWNERDRAWFIXED;
 
 						HWND hwndCombo = UT_CreateWindowEx ( 0L,   // No extended styles.
-							"COMBOBOX",						// Class name.
-							"",								// Default text.
+							L"COMBOBOX",						// Class name.
+							L"",								// Default text.
 							dwStyle,						// Styles and defaults.
 							0, 2, iWidth, 250,				// Size and position.
 							m_hwnd,							// Parent window.
@@ -696,13 +704,13 @@ bool EV_Win32Toolbar::synthesize(void)
 						 * Hack to create a combobox that is readonly, but which is capable of displaying text in 
 						 * the edit control which differs from that in the drop-down list like GTK combos.
 						 */
-						HWND hwndEdit = FindWindowEx(hwndCombo, 0, NULL, NULL);
+						HWND hwndEdit = FindWindowExW(hwndCombo, 0, NULL, NULL);
 						if (!hwndEdit)
 							UT_DEBUGMSG(("Toolbar: Failed to get handle of combos edit controls. Not setting read-only.\n"));
 						else
-							SendMessage(hwndEdit, EM_SETREADONLY, (WPARAM)TRUE, (LPARAM)0);
-						SendMessage(hwndCombo, WM_SETFONT, (WPARAM)GetStockObject(DEFAULT_GUI_FONT), MAKELPARAM(TRUE, 0));
-						SendMessage(hwndCombo, CB_SETDROPPEDWIDTH,(WPARAM)pControl->getDroppedWidth(), 0);
+							SendMessageW(hwndEdit, EM_SETREADONLY, (WPARAM)TRUE, (LPARAM)0);
+						SendMessageW(hwndCombo, WM_SETFONT, (WPARAM)GetStockObject(DEFAULT_GUI_FONT), MAKELPARAM(TRUE, 0));
+						SendMessageW(hwndCombo, CB_SETDROPPEDWIDTH,(WPARAM)pControl->getDroppedWidth(), 0);
 
 						// populate it
 						if (pControl)
@@ -712,53 +720,56 @@ bool EV_Win32Toolbar::synthesize(void)
 							const UT_GenericVector<const char*> * v = pControl->getContents();
 							UT_ASSERT_HARMLESS(v);
 
-							SendMessage(hwndCombo, WM_SETREDRAW, FALSE,0);
+							SendMessageW(hwndCombo, WM_SETREDRAW, FALSE,0);
 
 							if (v)
 							{
 								UT_uint32 items = v->getItemCount();
 								int nIndex;
+                                UT_Win32LocaleString localised;
 								for (UT_uint32 k=0; k < items; k++)
 								{
-									char * sz = (char *)v->getNthItem(k);
-									nIndex = SendMessage(hwndCombo, CB_ADDSTRING,(WPARAM)0, (LPARAM)sz);
-									SendMessage(hwndCombo,CB_SETITEMDATA, nIndex, k);
+									localised.fromUTF8(v->getNthItem(k));									
+    								nIndex = SendMessageW(hwndCombo, CB_ADDSTRING,(WPARAM)0, (LPARAM)localised.c_str());
+ 	     							SendMessageW(hwndCombo,CB_SETITEMDATA, nIndex, k);
 								}
 							}
 
-							SendMessage(hwndCombo, WM_SETREDRAW, TRUE,0);
+							SendMessageW(hwndCombo, WM_SETREDRAW, TRUE,0);
 						}
 
 						// override the window procedure for the combo box
-						s_lpfnDefCombo = (WHICHPROC)GetWindowLong(hwndCombo, GWL_WNDPROC);
-						SetWindowLong(hwndCombo, GWL_WNDPROC, (LONG)_ComboWndProc);
-						SetWindowLong(hwndCombo, GWL_USERDATA, (LONG)this);
+						s_lpfnDefCombo = (WHICHPROC)GetWindowLongPtrW(hwndCombo, GWLP_WNDPROC);
+						SetWindowLongPtrW(hwndCombo, GWLP_WNDPROC, (LONG_PTR)_ComboWndProc);
+						SetWindowLongPtrW(hwndCombo, GWLP_USERDATA, (LONG_PTR)this);
 
 						// Get the handle to the tooltip window.
-						HWND hwndTT = (HWND)SendMessage(m_hwnd, TB_GETTOOLTIPS, 0, 0);
+						HWND hwndTT = (HWND)SendMessageW(m_hwnd, TB_GETTOOLTIPS, 0, 0);
 
 						if (hwndTT)
 						{
+                            UT_Win32LocaleString str;	
 							const char * szToolTip = pLabel->getToolTip();
 							if (!szToolTip || !*szToolTip)
 							{
 								szToolTip = pLabel->getStatusMsg();
 							}
 
+                            str.fromUTF8 (szToolTip);
 
 							// Fill in the TOOLINFO structure.
-							TOOLINFO ti;
+							TOOLINFOW ti;
 							ti.cbSize = sizeof(ti);
 							ti.uFlags = TTF_IDISHWND | TTF_CENTERTIP;
-							ti.lpszText = (char *) szToolTip;
+							ti.lpszText = (wchar_t *) str.c_str();
 							ti.hwnd = m_hwnd;		// TODO: should this be the frame?
-							ti.uId = (UINT)hwndCombo;
+							ti.uId = (UINT_PTR)hwndCombo;
 							// Set up tooltips for the combo box.
-							SendMessage(hwndTT, TTM_ADDTOOL, 0, (LPARAM)(LPTOOLINFO)&ti);
+							SendMessageW(hwndTT, TTM_ADDTOOLW, 0, (LPARAM)(LPTOOLINFOW)&ti);
 						}
 						
 						// bind this separator to its control
-						tbb.dwData = (DWORD) hwndCombo;
+						tbb.dwData = (DWORD_PTR) hwndCombo;
 
 						// for now, we never repopulate, so can just toss it
 						DELETEP(pControl);
@@ -814,7 +825,7 @@ bool EV_Win32Toolbar::synthesize(void)
 						ab.hInst = 0;
 						ab.nID = (LPARAM)hBitmap;						
 						
-						LRESULT iAddedAt = SendMessage(m_hwnd,TB_ADDBITMAP,1,(LPARAM)&ab);
+						LRESULT iAddedAt = SendMessageW(m_hwnd,TB_ADDBITMAP,1,(LPARAM)&ab);
 						UT_ASSERT(iAddedAt != -1);
 
 						tbb.iBitmap = iAddedAt;
@@ -826,7 +837,7 @@ bool EV_Win32Toolbar::synthesize(void)
 						// As long as translators don't cut the text short,
 						// we need to autosize just to squize anything insize 1280 :)
 						tbb.fsStyle |= TBSTYLE_AUTOSIZE;
-						tbb.iString = SendMessage(m_hwnd, TB_ADDSTRING, (WPARAM) 0, (LPARAM) (LPSTR) szLabel);
+						tbb.iString = SendMessageW(m_hwnd, TB_ADDSTRING, (WPARAM) 0, (LPARAM) (LPSTR) szLabel);
 					}
 					
 					if (pAction->getItemType() == EV_TBIT_ColorFore || pAction->getItemType() == EV_TBIT_ColorBack)
@@ -835,9 +846,9 @@ bool EV_Win32Toolbar::synthesize(void)
 
 						//tbb.fsStyle |=BTNS_WHOLEDROPDOWN;
 
-						DWORD dwStyle = SendMessage(m_hwnd, TB_GETEXTENDEDSTYLE, (WPARAM) 0, (LPARAM) 0);						
+						DWORD dwStyle = SendMessageW(m_hwnd, TB_GETEXTENDEDSTYLE, (WPARAM) 0, (LPARAM) 0);						
 						dwStyle |= TBSTYLE_EX_DRAWDDARROWS;																		
-						SendMessage(m_hwnd, TB_SETEXTENDEDSTYLE, (WPARAM) 0, (LPARAM) dwStyle);						
+						SendMessageW(m_hwnd, TB_SETEXTENDEDSTYLE, (WPARAM) 0, (LPARAM) dwStyle);						
 					}
 					
 				}
@@ -854,11 +865,11 @@ bool EV_Win32Toolbar::synthesize(void)
 		}
 
 		// add this button to the bar
-		SendMessage(m_hwnd, TB_ADDBUTTONS, (WPARAM) 1, (LPARAM) (LPTBBUTTON) &tbb);
+		SendMessageW(m_hwnd, TB_ADDBUTTONS, (WPARAM) 1, (LPARAM) (LPTBBUTTON) &tbb);
 	}
 
 	// figure out bar dimensions now that buttons are all there
-	SendMessage(m_hwnd, TB_AUTOSIZE, 0, 0); 
+	SendMessageW(m_hwnd, TB_AUTOSIZE, 0, 0); 
 	
 	if (bControls)
 	{
@@ -884,7 +895,7 @@ bool EV_Win32Toolbar::synthesize(void)
 					GetWindowRect(hwndCtrl, &r);
 					nHeight = r.bottom - r.top;
 
-					SendMessage(m_hwnd, TB_GETITEMRECT, (WPARAM) k, (LPARAM)(LPRECT) &r);
+					SendMessageW(m_hwnd, TB_GETITEMRECT, (WPARAM) k, (LPARAM)(LPRECT) &r);
 
 					nSep = (r.bottom - r.top - nHeight)/2;
 					if (nSep < 0)
@@ -928,8 +939,8 @@ HWND EV_Win32Toolbar::_getControlWindow(XAP_Toolbar_Id id)
 	HWND hwndCtrl;
 	UINT u = WmCommandFromItemId(id);
 
-	UT_uint32 k = SendMessage(m_hwnd, TB_COMMANDTOINDEX, (WPARAM) u, 0);
-	SendMessage(m_hwnd, TB_GETBUTTON, (WPARAM) k, (LPARAM)(LPTBBUTTON) &tbb);
+	UT_uint32 k = SendMessageW(m_hwnd, TB_COMMANDTOINDEX, (WPARAM) u, 0);
+	SendMessageW(m_hwnd, TB_GETBUTTON, (WPARAM) k, (LPARAM)(LPTBBUTTON) &tbb);
 	UT_ASSERT(tbb.idCommand == (int) u);
 	UT_ASSERT(tbb.fsStyle & TBSTYLE_SEP);
 
@@ -996,9 +1007,7 @@ bool EV_Win32Toolbar::refreshToolbar(AV_View * pView, AV_ChangeMask mask)
 		switch (pLayoutItem->getToolbarLayoutFlags())
 		{
 		case EV_TLF_Normal:
-			{
-				_refreshItem(pView, pAction, id);
-			}
+			_refreshItem(pView, pAction, id);
 			break;
 			
 		case EV_TLF_Spacer:
@@ -1044,7 +1053,7 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 			{
 				bool bGrayed = EV_TIS_ShouldBeGray(tis);
 
-				SendMessage(m_hwnd, TB_ENABLEBUTTON, u, (LONG)!bGrayed) ;
+				SendMessageW(m_hwnd, TB_ENABLEBUTTON, u, (!bGrayed ? 1 : 0)) ;
 
 				//UT_DEBUGMSG(("refreshToolbar: PushButton [%s] is %s\n",
 				//			m_pToolbarLabelSet->getLabel(id)->getToolbarLabel(),
@@ -1058,8 +1067,8 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 				bool bGrayed = EV_TIS_ShouldBeGray(tis);
 				bool bToggled = EV_TIS_ShouldBeToggled(tis);
 				
-				SendMessage(m_hwnd, TB_ENABLEBUTTON, u, (LONG)!bGrayed);
-				SendMessage(m_hwnd, TB_CHECKBUTTON, u, (LONG)bToggled);
+				SendMessageW(m_hwnd, TB_ENABLEBUTTON, u, (!bGrayed ? 1 : 0));
+				SendMessageW(m_hwnd, TB_CHECKBUTTON, u, (bToggled ? 1 : 0));
 
 				//UT_DEBUGMSG(("refreshToolbar: ToggleButton [%s] is %s and %s\n",
 				//			 m_pToolbarLabelSet->getLabel(id)->getToolbarLabel(),
@@ -1080,26 +1089,25 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 				// NOTE: we always update the control even if !szState
 				if (!szState)
 				{
-					int idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)szState);
+					int idx = SendMessageW(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)szState);
 					if (idx==CB_ERR)
-						SetWindowText(hwndCombo, "");
+						SetWindowTextW(hwndCombo, L"");
 					break;
 				}					
 				
-				szState = XAP_EncodingManager::get_instance()->strToNative(szState, "UTF-8");
-				
 				// Find the proper non-localised text
-				const char* pLocalised = szState;
+                UT_Win32LocaleString localised;
 				if (id==AP_TOOLBAR_ID_FMT_STYLE)
 				{
-						pt_PieceTable::s_getLocalisedStyleName(pLocalised, utf8);
-						pLocalised = utf8.utf8_str();
-						str = AP_Win32App::s_fromUTF8ToWinLocale(pLocalised);
-						pLocalised = str.c_str();						
-				}
+                        pt_PieceTable::s_getLocalisedStyleName(szState, utf8);
+						localised.fromUTF8 (utf8.utf8_str());
+                }       
+                 else
+    					localised.fromUTF8 (szState);
 					
-												
-				int idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)pLocalised);
+                int idx = SendMessageW(hwndCombo, CB_FINDSTRINGEXACT, (WPARAM)-1, (LPARAM)localised.c_str());
+				if (idx!=CB_ERR)
+					SendMessageW(hwndCombo, CB_SETCURSEL, idx, NULL);
 				/*
 				 * If the string didn't exist within the combos list, we handle things differently for
 				 * different combos.
@@ -1116,7 +1124,7 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 					 */
 					case AP_TOOLBAR_ID_FMT_SIZE:
 					case AP_TOOLBAR_ID_FMT_FONT:
-						idx = SendMessage(hwndCombo, WM_SETTEXT, (WPARAM)-1, (LPARAM)pLocalised);
+						idx = SendMessageW(hwndCombo, WM_SETTEXT, (WPARAM)-1, (LPARAM)localised.c_str());
 						if (idx == CB_ERR)
 						{
 							UT_DEBUGMSG(("refreshToolbar: Failed to set text for font combo.\n"));
@@ -1127,7 +1135,8 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 					 */
 					case AP_TOOLBAR_ID_ZOOM:
 						pSS = XAP_App::getApp()->getStringSet();
-						idx = SendMessage(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)pSS->getValue(XAP_STRING_ID_TB_Zoom_Percent));
+                        localised.fromUTF8 (pSS->getValue(XAP_STRING_ID_TB_Zoom_Percent));
+						idx = SendMessageW(hwndCombo, CB_SELECTSTRING, (WPARAM)-1, (LPARAM)localised.c_str());
 						break;
 
 					case AP_TOOLBAR_ID_FMT_STYLE:
@@ -1166,7 +1175,7 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 bool EV_Win32Toolbar::getToolTip(LPARAM lParam)
 {
 	UT_ASSERT(lParam);
-	LPTOOLTIPTEXT lpttt = (LPTOOLTIPTEXT) lParam;
+	LPTOOLTIPTEXTW lpttt = (LPTOOLTIPTEXTW) lParam;
 
 	// who's asking?
 	UINT idButton = lpttt->hdr.idFrom;
@@ -1190,13 +1199,15 @@ bool EV_Win32Toolbar::getToolTip(LPARAM lParam)
 
 	if (szToolTip && *szToolTip)
 	{
-		// here 'tis
-		strncpy(lpttt->lpszText, szToolTip, 80);
+		UT_Win32LocaleString str;
+		str.fromUTF8 (szToolTip);
+		wcsncpy(lpttt->lpszText, str.c_str(),80);
 	}
 	else
 	{
 		lpttt->lpszText[0] = '\0';
 	}
+	lpttt->hinst=NULL;
 
 	return true;
 }
@@ -1222,7 +1233,7 @@ void EV_Win32Toolbar::hide(void)
 	const int iBand = _getBandForHwnd(m_hwnd);
 	if (iBand >= 0)
 	{
-		SendMessage(hRebar, RB_DELETEBAND, (WPARAM)iBand, 0);
+		SendMessageW(hRebar, RB_DELETEBAND, (WPARAM)iBand, 0);
 		m_bVisible = false;
 	}
 }
@@ -1237,13 +1248,13 @@ int EV_Win32Toolbar::_getBandForHwnd(HWND hToolbar) const
 	HWND hRebar = static_cast<XAP_Win32FrameImpl*>(m_pWin32Frame->getFrameImpl())->getToolbarWindow();
 
 	// If we ever get more than 20 toolbars I don't wanna be around.
-	REBARBANDINFO rbi;
+	REBARBANDINFOW rbi;
 	memset(&rbi, 0, sizeof(rbi));
 	rbi.cbSize = sizeof(rbi);
 	rbi.fMask  = RBBIM_CHILD;
 	for (int i = 0; i < 20; ++i)
 	{
-		if (!SendMessage(hRebar, RB_GETBANDINFO, (WPARAM)i, (LPARAM)&rbi))
+		if (!SendMessageW(hRebar, RB_GETBANDINFO, (WPARAM)i, (LPARAM)&rbi))
 		{
 			continue;
 		}
@@ -1258,7 +1269,7 @@ int EV_Win32Toolbar::_getBandForHwnd(HWND hToolbar) const
 void EV_Win32Toolbar::_addToRebar()
 {
 	// Get the height of the toolbar.
-	DWORD dwBtnSize = SendMessage(m_hwnd, TB_GETBUTTONSIZE, 0,0);
+	DWORD dwBtnSize = SendMessageW(m_hwnd, TB_GETBUTTONSIZE, 0,0);
 
 	RECT rc;
 	GetWindowRect(m_hwnd, &rc);
@@ -1266,10 +1277,10 @@ void EV_Win32Toolbar::_addToRebar()
 	UINT iWidth = rc.right - rc.left + 13;
 
 	// add this bar to the rebar
-	REBARBANDINFO  rbbi;
+	REBARBANDINFOW rbbi;
 	memset(&rbbi, 0, sizeof(rbbi));
 	// Initialize REBARBANDINFO
-	rbbi.cbSize = sizeof(REBARBANDINFO);
+	rbbi.cbSize = sizeof(REBARBANDINFOW);
 	rbbi.fMask =	RBBIM_COLORS	|	// clrFore and clrBack are valid
 					RBBIM_CHILD		|	// hwndChild is valid
 					RBBIM_CHILDSIZE	|	// cxMinChild and cyMinChild are valid
@@ -1288,7 +1299,7 @@ void EV_Win32Toolbar::_addToRebar()
 
 	HWND hRebar = static_cast<XAP_Win32FrameImpl*>(m_pWin32Frame->getFrameImpl())->getToolbarWindow();
 	// Add it at the the end
-	SendMessage(hRebar, RB_INSERTBAND, (WPARAM)-1, (LPARAM)&rbbi);
+	SendMessageW(hRebar, RB_INSERTBAND, (WPARAM)-1, (LPARAM)&rbbi);
 }
 
 
@@ -1350,10 +1361,10 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 // list of styles to the combo box.
 //
 // Try this....
-	SendMessage(hwndCombo, WM_SETREDRAW, FALSE, 0);
-	SendMessage(hwndCombo, CB_RESETCONTENT, 0 , 0);
+	SendMessageW(hwndCombo, WM_SETREDRAW, FALSE, 0);
+	SendMessageW(hwndCombo, CB_RESETCONTENT, 0 , 0);
 
-	SendMessage(hwndCombo, CB_SETDROPPEDWIDTH,
+	SendMessageW(hwndCombo, CB_SETDROPPEDWIDTH,
 				(WPARAM)pStyleC->getDroppedWidth(), 0);
 
 //
@@ -1375,21 +1386,19 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 	for (UT_sint32 k=0; k < v->getItemCount(); k++)
 	{
 		const char*	sz = (char *)v->getNthItem(k);
-		const char*	pLocalised = sz;
-
-		pt_PieceTable::s_getLocalisedStyleName(sz, utf8);
-		pLocalised = utf8.utf8_str();
-		str = AP_Win32App::s_fromUTF8ToWinLocale(pLocalised);
-		pLocalised = str.c_str();
+		UT_Win32LocaleString localised;
 		
-		nItem = SendMessage(hwndCombo, CB_ADDSTRING,(WPARAM)0, (LPARAM)pLocalised);
+		pt_PieceTable::s_getLocalisedStyleName(sz, utf8);
+		localised.fromUTF8 (utf8.utf8_str());
+		
+		nItem = SendMessageW(hwndCombo, CB_ADDSTRING,(WPARAM)0, (LPARAM)localised.c_str());
 		m_vecOrgStylesNames.addItem (new UT_UTF8String ((char *)v->getNthItem(k)));
-		SendMessage(hwndCombo, CB_SETITEMDATA,(WPARAM)nItem, (LPARAM)m_vecOrgStylesNames.getItemCount()-1);
+		SendMessageW(hwndCombo, CB_SETITEMDATA,(WPARAM)nItem, (LPARAM)m_vecOrgStylesNames.getItemCount()-1);
 	}
 //
 // Don't need this anymore and we don't like memory leaks in abi
 //
-	SendMessage(hwndCombo, WM_SETREDRAW, TRUE, 0);
+	SendMessageW(hwndCombo, WM_SETREDRAW, TRUE, 0);
 	InvalidateRect (hwndCombo, NULL, true);
 	delete pStyleC;
 //
