@@ -394,7 +394,9 @@ class ABI_EXPORT GR_Graphics
 	static GR_Graphics *   graphicsAllocator(GR_AllocInfo&){UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED); return NULL;}
 #endif
 
-	AllCarets *   allCarets(void);
+	AllCarets *	allCarets();
+	void		disableAllCarets();
+	void		enableAllCarets();
 	
 	UT_sint32	tdu(UT_sint32 layoutUnits) const;
 	UT_sint32	tlu(UT_sint32 deviceUnits) const;
@@ -602,31 +604,6 @@ class ABI_EXPORT GR_Graphics
 	virtual bool      getColor3D(GR_Color3D /*name*/, UT_RGBColor & /*color*/) 
 	{ return false; }
 
-	//
-	// Methods to deal with background repainting as used in the Unix FE. These
-	// make redraws really fast and fix bug 119
-	//
-	bool              isSpawnedRedraw(void) const;
-	void              setSpawnedRedraw(bool exposeState);
-
-	void              setPendingRect(UT_sint32 x,
-									 UT_sint32 y,
-									 UT_sint32 width,
-									 UT_sint32 height);
-
-	void              unionPendingRect( UT_Rect * pRect);
-	void              setRecentRect( UT_Rect * pRect);
-	const UT_Rect *   getPendingRect(void) const;
-	bool              isExposePending(void) const;
-	void              setExposePending(bool bExposePending);
-	bool              isExposedAreaAccessed(void) const;
-	void              setExposedAreaAccessed(bool bAccessedState);
-	void              setDontRedraw( bool bDontRedraw);
-	bool              isDontRedraw(void);
-	void              doRepaint(UT_Rect * rClip);
-	void              setDoMerge( bool bMergeState);
-	bool              doMerge(void) const;
-
 	const GR_Transform & getTransform() const {return m_Transform;}
 
 	/* returns true on success, false on failure */
@@ -747,8 +724,14 @@ class ABI_EXPORT GR_Graphics
 	UT_uint32         getPaintCount(void) const
 		{ return  m_paintCount;}
 
+	/* all drawing should happen between calls to these two functions. this
+	 * arranges for cairo contexts to be created/destroyed etc.  if you don't
+	 * call these functions, bad things can and will happen */
+	void beginPaint ();
+	void endPaint ();
+
 	static GR_Graphics* newNullGraphics();
-	
+
  protected:
 
 	GR_Graphics();
@@ -813,6 +796,7 @@ class ABI_EXPORT GR_Graphics
 											 int* pCharWidths = NULL);
 	
 	virtual GR_Image *	  genImageFromRectangle(const UT_Rect & r) = 0;
+
  private:
 	virtual bool _setTransform(const GR_Transform & /*tr*/)
 		{
@@ -820,10 +804,6 @@ class ABI_EXPORT GR_Graphics
 			return false;
 		}
 
-	// only called by GR_Painter
-	void beginPaint ();
-	void endPaint ();
-
  public:
 	// TODO -- this should not be public, create access methods !!!
 	//
@@ -848,6 +828,8 @@ class ABI_EXPORT GR_Graphics
 
 	bool m_bHave3DColors;
 
+	UT_uint32 m_paintCount;
+
  private:
 	GR_Caret *		 m_pCaret;
     bool             _PtInPolygon(UT_Point * pts,UT_uint32 nPoints,UT_sint32 x,UT_sint32 y);
@@ -869,8 +851,6 @@ class ABI_EXPORT GR_Graphics
 
 	UT_GenericStringMap<GR_Font*> m_hashFontCache;
 
-	UT_uint32 m_paintCount;
-
 	static UT_VersionInfo   s_Version;
 	static UT_uint32        s_iInstanceCount;
 	static UT_UCS4Char      s_cDefaultGlyph;
