@@ -446,7 +446,11 @@ UT_go_filename_simplify (const char *filename, UT_GODotDot dotdot,
 					isdir = TRUE;
 					break;
 				case UT_GO_DOTDOT_TEST: {
+#if GLIB_CHECK_VERSION(2,26,0) || defined(G_OS_WIN32)
+					GStatBuf statbuf;
+#else
 					struct stat statbuf;
+#endif
 					char savec = *q;
 					/*
 					 * Terminate the path so far so we can
@@ -1390,7 +1394,12 @@ UT_go_file_exists (char const *uri)
 
 	return FALSE;
 #else
+
+#if GLIB_CHECK_VERSION(2,26,0) || defined(G_OS_WIN32)
+	GStatBuf file_stat;
+#else
 	struct stat file_stat;
+#endif
 	char *filename = UT_go_filename_from_uri (uri);
 	int result = filename ? g_stat (filename, &file_stat) : -1;
 
@@ -1596,8 +1605,12 @@ UT_go_file_get_date (char const *uri, UT_GOFileDateType type)
 	}
 
 	gnome_vfs_file_info_unref (file_info);
+#else
+#if GLIB_CHECK_VERSION(2,26,0) || defined(G_OS_WIN32)
+	GStatBuf file_stat;
 #else
 	struct stat file_stat;
+#endif
 	char *filename = UT_go_filename_from_uri (uri);
 	int result = filename ? g_stat (filename, &file_stat) : -1;
 
@@ -1655,12 +1668,17 @@ check_program (char const *prog)
 }
 #endif
 
+#ifdef G_OS_WIN32
+#include "ut_Win32LocaleString.h"
+#endif
+
 GError *
 UT_go_url_show (gchar const *url)
 {
 #ifdef G_OS_WIN32
-	ShellExecute (NULL, "open", url, NULL, NULL, SW_SHOWNORMAL);
-
+	UT_Win32LocaleString str;
+	str.fromUTF8 (url);
+	ShellExecuteW (NULL, L"open", str.c_str(), NULL, NULL, SW_SHOWNORMAL);
 	return NULL;
 #else
 	GError *err = NULL;
