@@ -167,9 +167,10 @@ std::string UT_pathSuffix(std::string path)
 		slashpos++; // strip the leading / as well
 	}
 
-	size_t dotpos = path.find_first_of('.', slashpos);
+	size_t dotpos = path.find_last_of('.');
 	if (dotpos == std::string::npos)
 		return "";
+	if (dotpos <= slashpos) return "";
 
 	return std::string(path, dotpos, path.size() - dotpos);
 }
@@ -226,10 +227,13 @@ bool UT_isWordDelimiter(UT_UCSChar currentChar, UT_UCSChar followChar, UT_UCSCha
 		case G_UNICODE_DECIMAL_NUMBER:
 		case G_UNICODE_LETTER_NUMBER:
 		case G_UNICODE_OTHER_NUMBER:
+			return false;
 		case G_UNICODE_CONNECT_PUNCTUATION:
- 			return false;
+			return (currentChar == '_'); // _ is a word separator!
 
 		case G_UNICODE_OTHER_PUNCTUATION:
+		case G_UNICODE_INITIAL_PUNCTUATION:
+		case G_UNICODE_FINAL_PUNCTUATION:
 			switch (currentChar)
 			{
 				// some punctuation can be internal in word
