@@ -72,6 +72,36 @@ bool UT_XML_cloneNoAmpersands(gchar *& rszDest, const gchar * szSource)
 	return true;
 }
 
+bool UT_XML_cloneConvAmpersands(gchar *& rszDest, const gchar * szSource)
+{
+	if (szSource == NULL)
+		return false;
+
+	UT_uint32 length = strlen(szSource) + 1;
+	rszDest = static_cast<gchar *>(UT_calloc(length, sizeof(gchar)));
+
+	if (!rszDest)
+		return false;
+
+	const gchar * o = szSource;
+	gchar * n = rszDest;
+	while (*o != 0)
+	{
+		if (*o != '&')
+		{
+			*n = *o;
+		} else {
+			if (o[1] == '&') {
+				*n++ = '&';
+			}
+			else *n = '_';
+		}
+		n++; o++;
+	}
+
+	return true;
+}
+
 /* This uses the clone no ampersands but dumps into a static buffer */
 const gchar *UT_XML_transNoAmpersands(const gchar * szSource)
 {
@@ -896,6 +926,23 @@ bool UT_UCS4_isSentenceSeparator(UT_UCS4Char c)
 		return false;
 	}
 }
+
+bool UT_UCS4_isdigit(UT_UCS4Char c)
+{
+	if (c < 0x700) {
+		for (int i=0; i < G_N_ELEMENTS(digits_table); i++) {
+			if (c < digits_table[i].low) break;
+			if (c <= digits_table[i].high)
+				return true;
+		}
+	} else {
+		ucs_range * rng = static_cast<ucs_range *>(bsearch(&c, &digits_table, 
+			G_N_ELEMENTS(digits_table),sizeof(ucs_range),s_cmp_digits));
+		if (rng) return true;
+	}
+	return false;
+}
+
 /* copies exactly n-chars from src to dest; NB! does not check for 00 i src
 */
 UT_UCS4Char * UT_UCS4_strncpy(UT_UCS4Char * dest, const UT_UCS4Char * src, UT_uint32 n)
@@ -1193,6 +1240,24 @@ UT_uint32 UT_UCS4_strlen(const UT_UCS4Char * string)
 	return i;
 }
 
+UT_uint32 UT_UCS4_strlen_as_char(const UT_UCS4Char * string)
+{
+	UT_uint32 i = 0;
+
+	char d[4]; // assuming that any character can be coded with no more that 4 bytes.
+
+	UT_Wctomb w(XAP_EncodingManager::get_instance()->getNative8BitEncodingName());
+
+	while (*string != 0)
+	  {
+		int length;
+		w.wctomb_or_fallback(d,length,*string++);
+		i+=length;
+	  }
+
+	return i;
+}
+
 UT_UCS4Char * UT_UCS4_strcpy(UT_UCS4Char * dest, const UT_UCS4Char * src)
 {
 	UT_ASSERT(dest);
