@@ -39,6 +39,8 @@ G_BEGIN_DECLS
 
 // this function allocates (and returns a pointer to) new memory for the new string
 ABI_EXPORT bool  UT_XML_cloneNoAmpersands(gchar *& rszDest, const gchar * szSource);
+// replaces &X -> _X; allocates buffer
+ABI_EXPORT bool  UT_XML_cloneConvAmpersands(gchar *& rszDest, const gchar * szSource);
 // This function uses a static buffer to do the translation
 ABI_EXPORT const gchar *  UT_XML_transNoAmpersands(const gchar * szSource);
 
@@ -131,18 +133,18 @@ ABI_EXPORT bool  UT_UCS4_isupper(UT_UCS4Char c);
 ABI_EXPORT bool  UT_UCS4_islower(UT_UCS4Char c);
 ABI_EXPORT bool  UT_UCS4_isalpha(UT_UCS4Char c);
 ABI_EXPORT bool	 UT_UCS4_isSentenceSeparator(UT_UCS4Char c);
+ABI_EXPORT bool  UT_UCS4_isdigit(UT_UCS4Char c);
 #define UT_UCS4_isalnum(x)	(UT_UCS4_isalpha(x) || UT_UCS4_isdigit(x)) // HACK: not UNICODE-safe
 ABI_EXPORT bool UT_UCS4_isspace(UT_UCS4Char c);
 #define UT_UCS4_ispunct(x)   ((!UT_UCS4_isspace(x)  &&  !UT_UCS4_isalnum(x)  &&  (x)>' '))  // HACK: not UNICODE safe
 
-#define UT_UCS4_isdigit(x)	(((x) >= '0') && ((x) <= '9'))  // TODO: make UNICODE-wise
-
 // the naming convention has deviated from the above.  it's kind
 // of a mutant libc/C++ naming convention.
 ABI_EXPORT UT_sint32 		 UT_UCS4_strcmp(const UT_UCS4Char* left, const UT_UCS4Char* right);
 ABI_EXPORT UT_UCS4Char * 	 UT_UCS4_strstr(const UT_UCS4Char * phaystack, const UT_UCS4Char * pneedle);
 ABI_EXPORT UT_UCS4Char * 	 UT_UCS4_stristr(const UT_UCS4Char * phaystack, const UT_UCS4Char * pneedle);
 ABI_EXPORT UT_uint32 		 UT_UCS4_strlen(const UT_UCS4Char * string);
+ABI_EXPORT UT_uint32		 UT_UCS4_strlen_as_char(const UT_UCS4Char * string);
 ABI_EXPORT UT_UCS4Char * 	 UT_UCS4_strcpy(UT_UCS4Char * dest, const UT_UCS4Char * src);
 ABI_EXPORT UT_UCS4Char * 	 UT_UCS4_strcpy_char(UT_UCS4Char * dest, const char * src);
 ABI_EXPORT UT_UCS4Char * 	 UT_UCS4_strncpy_char(UT_UCS4Char * dest, const char * src, int);
