@@ -23,7 +23,11 @@
 #include <ctype.h>
 
 #ifdef WIN32
-#  include <winsock.h> // this is where timeval etc is defined ...
+#ifdef _MSC_VER
+#  include <winsock.h> // this is where timeval should be ...
+#else
+#  include <mswsock.h> // this is where timeval etc is defined ...
+#endif
 #else
 #  include <sys/time.h> // this is where timeval should be ...
 #endif
@@ -101,6 +105,8 @@ bool  UT_UUID::_parse(const char * in, struct uuid &uuid) const
     const char  *cp;
     char        buf[3];
 
+    UT_return_val_if_fail(in, false);
+
 	// verify this is valid uuid string
     if(strlen(in) != 36)
         return false;
