@@ -798,24 +798,18 @@ get_ensured_style (GtkWidget * w)
 
 /*!
  * Creates a new GdkDrawingArea with the proper colormap and visual
- * NB: drawing areas returned are not double buffered
+ * This returns a single-buffered widget.
+ * DEPRECATED: please use gtk_drawing_area_new() directly and make your
+ * implementation work with double-buffering in new code!
  */
 GtkWidget *createDrawingArea ()
 {
   GtkWidget *area;
   
   area = gtk_drawing_area_new ();
-
-  setupDrawingArea(area);
-  return area;
-}
-
-/*!
- * Performs setup as needed for a drawing area
- */
-void setupDrawingArea (GtkWidget *area)
-{
   gtk_widget_set_double_buffered(area, FALSE);
+
+  return area;
 }
 
 /*!
