@@ -45,8 +45,16 @@ class XAP_Dialog;
                                                     std::string _s;           \
                                                     pSS->getValueUTF8(id,_s); \
                                                     UT_XML_cloneNoAmpersands(newstr, _s.c_str()); \
-                                                    } while (0)
-												   
+							} while (0);
+         
+// This macro is for use in Unix dialogs where the accelerator characters
+// strings need to be converted to underscores.
+#define	CONVERT_TO_ACC_STRING(str, id, newstr)		do { \
+                                                    FREEP(newstr); \
+                                                    std::string _s;           \
+                                                    pSS->getValueUTF8(id,_s); \
+                                                    UT_XML_cloneConvAmpersands(newstr, _s.c_str()); \
+							} while (0);
 
 
 /** load a GtkBuilder for a dialog using the standard path.
@@ -73,9 +81,6 @@ GtkStyle * get_ensured_style (GtkWidget * w);
 // creates a GtkDrawingArea, and pushes/pops correct visual and colormap
 GtkWidget *createDrawingArea ();
 
-// Sets up a drawing area, normally called by CreateDrawingArea
-void setupDrawingArea (GtkWidget *area);
-
 void abiSetupModalDialog(GtkDialog * me, XAP_Frame *pFrame, XAP_Dialog * pDlg, gint dfl_id);
 gint abiRunModalDialog(GtkDialog * me, bool destroyDialog, AtkRole role = ATK_ROLE_DIALOG);
 gint abiRunModalDialog(GtkDialog * me, XAP_Frame *pFrame, XAP_Dialog * pDlg, gint dfl_id, bool destroyDialog, AtkRole role = ATK_ROLE_DIALOG);
