@@ -32,6 +32,7 @@
 #include "ut_debugmsg.h"
 #include "ut_path.h"
 #include "ut_Win32Uuid.h"
+#include "ut_Win32LocaleString.h"
 #include "xap_Win32App.h"
 #include "xap_Win32Clipboard.h"
 #include "xap_Frame.h"
@@ -54,10 +55,8 @@
 #include <w32api.h>
 #endif
 
-#ifdef UNICODE
-char XAP_Win32App::m_buffer[MAX_CONVBUFFER] = "";
+char XAP_Win32App::m_buffer[MAX_CONVBUFFER*6] = "";
 WCHAR XAP_Win32App::m_wbuffer[MAX_CONVBUFFER] = L"";
-#endif
 
 // do not want to include wv.h here, since it defines some types that
 // overlap with stuff in windov.h
@@ -119,7 +118,7 @@ XAP_Win32App::XAP_Win32App(HINSTANCE hInstance, const char * szAppName)
 #if ABI_OPT_DISABLE_USP
 		HINSTANCE hUniscribe = NULL;
 #else
-		HINSTANCE hUniscribe = LoadLibrary("usp10.dll");
+		HINSTANCE hUniscribe = LoadLibraryW(L"usp10.dll");
 #endif
 
 		if(hUniscribe && (NULL == g_getenv("ABIWORD_DISABLE_UNISCRIBE")))
@@ -169,8 +168,8 @@ bool XAP_Win32App::initialize(const char * szKeyBindingsKey, const char * szKeyB
 
 	m_pSlurp = new XAP_Win32Slurp(this);
 	m_pSlurp->connectSlurper();
-	char bufExePathname[4096];
-	GetModuleFileNameA(NULL,bufExePathname,G_N_ELEMENTS(bufExePathname)); //!TODO Using ANSI function
+	WCHAR bufExePathname[2048];
+	GetModuleFileNameW(NULL,bufExePathname,G_N_ELEMENTS(bufExePathname));
 
 	// TODO these are Application-Specific values.  Move them out of here.
 	m_pSlurp->stuffRegistry(".abw",getApplicationName(),bufExePathname,"application/abiword");
@@ -199,13 +198,13 @@ XAP_Toolbar_ControlFactory * XAP_Win32App::getControlFactory(void)
 	return &m_controlFactory;
 }
 
-UT_uint32 XAP_Win32App::_getExeDir(char* pDirBuf, UT_uint32 iBufLen) // ansi only dirs for now
+UT_uint32 XAP_Win32App::_getExeDir(LPWSTR pDirBuf, UT_uint32 iBufLen)
 {
-	UT_uint32 iResult = GetModuleFileNameA(NULL, pDirBuf, iBufLen); //!TODO Using ANSI function
+	UT_uint32 iResult = GetModuleFileNameW(NULL, pDirBuf, iBufLen);
 
 	if (iResult > 0)
 	{
-		char* p = pDirBuf + strlen(pDirBuf);
+		LPWSTR p = pDirBuf + wcslen(pDirBuf);
 		while (*p != '\\')
 		{
 			p--;
@@ -213,66 +212,172 @@ UT_uint32 XAP_Win32App::_getExeDir(char* pDirBuf, UT_uint32 iBufLen) // ansi onl
 		UT_ASSERT(p > pDirBuf);
 		p++;
 		*p = 0;
+		iResult = (p - pDirBuf);
 	}
 
 	return iResult;
 }
 
-const char * XAP_Win32App::getUserPrivateDirectory(void) // ansi only dirs for now
+static bool isWriteable(LPWSTR lpPath)
+{
+	bool  result = false;
+	DWORD len = lstrlenW(lpPath);
+	DWORD rem = MAX_PATH - len - 1;
+	DWORD err;
+	if (rem < 13) return false;
+
+	lstrcpyW(&lpPath[len],L"/abiword.flg");
+	if (CreateDirectoryW(lpPath,NULL)) {
+		RemoveDirectoryW(lpPath);
+		err=GetLastError();
+		if (err != ERROR_ACCESS_DENIED) result=true;
+	} else {
+		err=GetLastError();
+	}
+	lpPath[len]=0;
+	return result;
+}
+
+const char * XAP_Win32App::getUserPrivateDirectory(void)
 {
 	/* return a pointer to a static buffer */
 
-	const char * szAbiDir = "AbiSuite";
+	LPCWSTR szAbiDir = L"AbiSuite";
 
-	static char buf[PATH_MAX];
+	bool path_ok = false;
+
+	static WCHAR wbuf[PATH_MAX];
+	static char buf[PATH_MAX*6];
 	memset(buf,0,sizeof(buf));
 
 	DWORD len, len1, len2;
 
-	// On NT, USERPROFILE seems to be set to the directory containing per-user
-	// information.  we'll try that first.
+	UT_Win32LocaleString str;
+	UT_UTF8String utf8;
 
-	len = GetEnvironmentVariableA("USERPROFILE",buf,PATH_MAX); //!TODO Using ANSI function
+	// On W2K and later, APPDATA seems to be set to the directory containing per-user
+	// information.
+
+	len = GetEnvironmentVariableW(L"APPDATA",wbuf,PATH_MAX);
 	if (len)
 	{
-		UT_DEBUGMSG(("Getting preferences directory from USERPROFILE [%s].\n",buf));
+		if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+		str.fromLocale(wbuf);
+		utf8=str.utf8_str();
+		UT_DEBUGMSG(("Getting preferences directory from USERPROFILE [%s].\n",utf8.utf8_str()));
+#endif
 	}
-	else
+
+	if (!path_ok)
+	{
+		// On NT, USERPROFILE seems to be modern equivalent of $HOME
+
+		len = GetEnvironmentVariableW(L"USERPROFILE",wbuf,PATH_MAX);
+		if (len)
+		{
+			if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+			str.fromLocale(wbuf);
+			utf8=str.utf8_str();
+			UT_DEBUGMSG(("Getting preferences directory from USERPROFILE [%s].\n",utf8.utf8_str()));
+#endif
+		}
+	}
+
+	if (!path_ok)
 	{
 		// If that doesn't work, look for HOMEDRIVE and HOMEPATH.  HOMEPATH
 		// is mentioned in the GetWindowsDirectory() documentation at least.
 		// These may be set if the SysAdmin did so in the Admin tool....
 
-		len1 = GetEnvironmentVariableA("HOMEDRIVE",buf,PATH_MAX); //!TODO Using ANSI function
-		len2 = GetEnvironmentVariableA("HOMEPATH",&buf[len1],PATH_MAX-len1); //!TODO Using ANSI function
+		len1 = GetEnvironmentVariableW(L"HOMEDRIVE",wbuf,PATH_MAX);
+		len2 = GetEnvironmentVariableW(L"HOMEPATH",&wbuf[len1],PATH_MAX-len1);
 		if (len1 && len2)
 		{
-			UT_DEBUGMSG(("Getting preferences directory from HOMEDRIVE and HOMEPATH [%s].\n",buf));
-		}
-		else
-		{
-			// If that doesn't work, let's just stick it in the WINDOWS directory.
-
-			len = GetWindowsDirectoryA(buf,PATH_MAX); //!TODO Using ANSI function
-			if (len)
-			{
-				UT_DEBUGMSG(("Getting preferences directory from GetWindowsDirectory() [%s].\n",buf));
-			}
-			else
-			{
-				// If that doesn't work, stick it in "C:\"...
-
-				strcpy(buf,"C:\\");
-			}
+			if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+			str.fromLocale(wbuf);
+			utf8=str.utf8_str();
+			UT_DEBUGMSG(("Getting preferences directory from HOMEDRIVE and HOMEPATH [%s].\n",utf8.utf8_str()));
+#endif
 		}
 	}
 
-	if (strlen(buf)+strlen(szAbiDir)+2 >= PATH_MAX)
+	if (!path_ok)
+	{
+		// If that doesn't work, let's just stick it in the WINDOWS directory.
+
+		len = GetWindowsDirectoryW(wbuf,PATH_MAX);
+		if (len)
+		{
+			if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+			str.fromLocale(wbuf);
+			utf8=str.utf8_str();
+			UT_DEBUGMSG(("Getting preferences directory from GetWindowsDirectory() [%s].\n",utf8.utf8_str()));
+#endif
+		}
+	}
+
+	if (!path_ok)
+	{
+		// If that doesn't work, stick it in "C:\"...
+
+		lstrcpyW(wbuf,L"C:\\");
+		if (isWriteable(wbuf)) path_ok=true;
+		UT_DEBUGMSG(("Getting preferences directory defaulted to C:\\.\n"));
+	}
+
+	if (!path_ok)
+	{
+		// As penultimate resort try to use temporary dir
+
+		len = GetTempPathW(MAX_PATH,wbuf);
+		if (len)
+		{
+			if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+			str.fromLocale(wbuf);
+			utf8=str.utf8_str();
+			UT_DEBUGMSG(("Getting preferences directory from GetTempPath() [%s].\n",utf8.utf8_str()));
+#endif
+		}
+	}
+
+	if (!path_ok)
+	{
+		// As last resort trying to use TMP dir
+
+		len = GetEnvironmentVariableW(L"TMP",wbuf,PATH_MAX);
+		if (len)
+		{
+			if (isWriteable(wbuf)) path_ok=true;
+#ifdef DEBUG
+			str.fromLocale(wbuf);
+			utf8=str.utf8_str();
+			UT_DEBUGMSG(("Getting preferences directory from TMP [%s].\n",utf8.utf8_str()));
+#endif
+		}
+	}
+
+	UT_ASSERT(path_ok=true)
+
+	if (lstrlenW(wbuf)+lstrlenW(szAbiDir)+2 >= PATH_MAX)
 		return NULL;
 
-	if (buf[strlen(buf)-1] != '\\')
-		strcat(buf,"\\");
-	strcat(buf,szAbiDir);
+	if (wbuf[lstrlenW(wbuf)-1] != L'\\')
+		lstrcatW(wbuf,L"\\");
+	lstrcatW(wbuf,szAbiDir);
+
+#ifdef NO_WIN32_UNICODE_SUPPORT_YET
+	WideCharToMultiByte(CP_ACP,0,wbuf,-1,buf,MAX_PATH,"_",NULL);
+#else
+	str.fromLocale(wbuf);
+	utf8=str.utf8_str();
+	strcpy(buf,utf8.utf8_str());
+#endif
+
 	return buf;
 }
 
@@ -298,12 +403,14 @@ static void s_buildDirName(const UT_Vector& vDirComponents, UT_uint32 iComponent
 
 void XAP_Win32App::_setAbiSuiteLibDir(void)
 {
-	char buf[PATH_MAX];
+	char *utf8;
+	WCHAR buf[PATH_MAX];
 
 	// see if ABIWORD_DATADIR was set in the environment
-	if (GetEnvironmentVariableA("ABIWORD_DATADIR",buf,sizeof(buf)) > 0) //!TODO Using ANSI function
+	if (GetEnvironmentVariableW(L"ABIWORD_DATADIR",buf,sizeof(buf)) > 0)
 	{
-		char * p = buf;
+		utf8 = (char*) getUTF8String(buf);
+		char * p = utf8;
 		int len = strlen(p);
 		if ( (p[0]=='"') && (p[len-1]=='"') )
 		{
@@ -323,15 +430,19 @@ void XAP_Win32App::_setAbiSuiteLibDir(void)
 		char *base;
 		size_t len, baselen;
 
-		len = strlen(buf);
-		base = g_path_get_basename(buf);
+		utf8 = (char*) getUTF8String(buf);
+
+		len = strlen(utf8);
+		base = g_path_get_basename(utf8);
 		baselen = strlen(base);
 		g_free (base), base = NULL;
-		buf[len - baselen - 1] = '\0';
+		if (len+1 > baselen && utf8[len - baselen - 2] == '\\')
+			utf8[len - baselen - 2] = 0;
+		else utf8[len - baselen - 1] = '\0';
 #ifdef _MSC_VER
-		XAP_App::_setAbiSuiteLibDir(buf);
+		XAP_App::_setAbiSuiteLibDir(utf8);
 #else
-		gchar * dir = g_build_filename(buf, "share", PACKAGE "-" ABIWORD_SERIES, NULL);
+		gchar * dir = g_build_filename(utf8, "share", PACKAGE "-" ABIWORD_SERIES, NULL);
 		XAP_App::_setAbiSuiteLibDir(dir);
 		g_free (dir), dir = NULL;
 #endif
@@ -471,16 +582,9 @@ void XAP_Win32App::_setBidiOS(void)
 
 const char * XAP_Win32App::getDefaultEncoding () const
 {
-	#ifdef UNICODE
-	return "UTF-8";
-	#else
-	XAP_EncodingManager * pEncodingManager = XAP_EncodingManager::get_instance();
-	return pEncodingManager->getNativeSystemEncodingName();
-	#endif
-	
+	return "UTF-8";	
 }
 
-#ifdef UNICODE
 const WCHAR * XAP_Win32App::getWideString (const char * utf8input)
 {
 	int wlen = MultiByteToWideChar(CP_UTF8, 0, utf8input, -1, NULL, 0);
@@ -502,34 +606,20 @@ const char * XAP_Win32App::getUTF8String (const WCHAR * p_str)
 {
 	int len = WideCharToMultiByte(CP_UTF8, 0, p_str, -1, NULL, 0, NULL, NULL);
 	UT_ASSERT(len);
-	if (len && (len < MAX_CONVBUFFER)) {
-		len = WideCharToMultiByte(CP_UTF8, 0, p_str, -1, m_buffer, MAX_CONVBUFFER, NULL, NULL);
+	if (len && (len < MAX_CONVBUFFER*6)) {
+		len = WideCharToMultiByte(CP_UTF8, 0, p_str, -1, m_buffer, MAX_CONVBUFFER*6, NULL, NULL);
 		UT_ASSERT(len);
 		return m_buffer;
 	}
 	else 
 	{
-		UT_ASSERT(len < MAX_CONVBUFFER);
+		UT_ASSERT(len < MAX_CONVBUFFER*6);
 		UT_DEBUGMSG(("getUTF8String:converted string too long %d", len));
 		return NULL;
 	}
 }
 
 
-#else
-const char * XAP_Win32App::getWideString (const char * utf8input)
-{
-	return utf8input;
-}
-
-const char * XAP_Win32App::getUTF8String (const char * p_str)
-{
-	return p_str;
-}
-
-#endif
-
-
 void XAP_Win32App::getDefaultGeometry(UT_uint32& width, UT_uint32& height, UT_uint32& flags)
 {
 	flags |= PREF_FLAG_GEOMETRY_MAXIMIZED;
