@@ -851,22 +851,13 @@ bool XAP_App::findAbiSuiteLibFile(UT_String & path, const char * filename, const
 
 	bool bFound = false;
 
-	const char * dir = getUserPrivateDirectory();
-	if (dir)
+	const char * dir[2] = {
+		getUserPrivateDirectory(),
+		getAbiSuiteLibDir()
+	};
+	for (int i=0; !bFound && i<2; i++)
 	{
-		path = dir;
-		if (subdir)
-		{
-			path += G_DIR_SEPARATOR;
-			path += subdir;
-		}
-		path += G_DIR_SEPARATOR;
-		path += filename;
-		bFound = UT_isRegularFile (path.c_str ());
-	}
-	if (!bFound && (dir = getAbiSuiteLibDir()))
-	{
-		path = dir;
+		path = dir[i];
 		if (subdir)
 		{
 			path += G_DIR_SEPARATOR;
@@ -974,12 +965,12 @@ void XAP_App::rememberFocussedFrame( void * pJustFocussedFrame)
 
 UT_sint32 XAP_App::safefindFrame( XAP_Frame * f) const
 {
-	long ff = reinterpret_cast<long>(f);
+	size_t ff = reinterpret_cast<size_t>(f);
 	UT_sint32 num_frames = m_vecFrames.getItemCount();
 	UT_sint32 i;
 	for( i = 0; i< num_frames; i++)
 	{
-		long lf = reinterpret_cast<long>( m_vecFrames.getNthItem(i));
+		size_t lf = reinterpret_cast<size_t>( m_vecFrames.getNthItem(i));
 		if( lf == ff) break;
 	}
 	if( i == num_frames ) i = -1;
