@@ -46,6 +46,8 @@
 #include "fl_SectionLayout.h"
 #include "fb_LineBreaker.h"
 #include "ut_string_class.h"
+#include "ut_misc.h"
+#include "pp_PropertyMap.h"
 
 // number of DocPositions occupied by the block strux
 #define fl_BLOCK_STRUX_OFFSET	1
@@ -390,6 +392,18 @@ public:
 												UT_UTF8String & sWord,
 												bool bIgnoreSpace) const;
 	bool                   itemizeSpan(PT_BlockOffset blockOffset, UT_uint32 len,GR_Itemization & I);
+	const UT_RGBColor      getShadingingForeColor(void) const;
+	const UT_RGBColor      getShadingingBackColor(void) const;
+	UT_sint32              getPattern(void) const;
+
+	const PP_PropertyMap::Line & getBottom () const { return m_lineBottom; }
+	const PP_PropertyMap::Line & getLeft ()   const { return m_lineLeft; }
+	const PP_PropertyMap::Line & getRight ()  const { return m_lineRight; }
+	const PP_PropertyMap::Line & getTop ()    const { return m_lineTop; }
+
+	bool                   hasBorders(void) const;
+	bool                   canMergeBordersWithPrev(void) const;
+	bool                   canMergeBordersWithNext(void) const;
 
 #ifdef ENABLE_SPELL
 	/** put in queue for spellchecking after prev. If prev == NULL is put at the head */
@@ -452,6 +466,7 @@ protected:
 	bool					_doInsertBookmarkRun(PT_BlockOffset blockOffset);
 	bool					_doInsertHyperlinkRun(PT_BlockOffset blockOffset);
 	bool					_doInsertAnnotationRun(PT_BlockOffset blockOffset);
+	bool					_doInsertRDFAnchorRun(PT_BlockOffset blockOffset);
 	bool					_doInsertMathRun(PT_BlockOffset blockOffset,PT_AttrPropIndex indexAP,PL_ObjectHandle oh);
 	bool					_doInsertEmbedRun(PT_BlockOffset blockOffset,PT_AttrPropIndex indexAP,PL_ObjectHandle oh);
 //	bool					_deleteBookmarkRun(PT_BlockOffset blockOffset);
@@ -547,6 +562,16 @@ protected:
 	bool                    m_bForceSectionBreak;
 	bool                    m_bPrevListLabel;
     UT_sint32               m_iAdditionalMarginAfter;
+	UT_RGBColor             m_ShadingForeColor;
+	UT_RGBColor             m_ShadingBackColor;
+	UT_sint32               m_iPattern;
+
+	PP_PropertyMap::Line    m_lineBottom;
+	PP_PropertyMap::Line    m_lineLeft;
+	PP_PropertyMap::Line    m_lineRight;
+	PP_PropertyMap::Line    m_lineTop;
+	bool                    m_bCanMergeBordersWithNext;
+	bool                    m_bHasBorders;
 };
 
 /*
