@@ -1415,7 +1415,7 @@ void fl_TableLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		xxx_UT_DEBUGMSG(("Processing Column width string %s \n",pszRelColumnProps));
 		UT_VECTOR_PURGEALL(fl_ColProps *,m_vecColProps);
 		m_vecColProps.clear();
-		UT_String sProps = pszColumnProps;
+		UT_String sProps = pszRelColumnProps;
 		UT_sint32 sizes = sProps.size();
 		UT_sint32 i =0;
 		UT_sint32 j =0;
@@ -1929,7 +1929,8 @@ fl_CellLayout::fl_CellLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh, PT_At
 	  m_bCellPositionedOnPage(false),
 	  m_iCellHeight(0),
 	  m_iCellWidth(0),
-	  m_iNumNestedTables(0)
+	  m_iNumNestedTables(0),
+	  m_iVertAlign(0)
 {
 	createCellContainer();
 }
@@ -2051,6 +2052,7 @@ void fl_CellLayout::setCellContainerProperties(fp_CellContainer * pCell)
 	pCell->setLeftStyle(m_lineLeft);
 	pCell->setRightStyle(m_lineRight);
 	pCell->setTopStyle(m_lineTop);
+	pCell->setVertAlign(m_iVertAlign);
 	if(m_pGraphicImage)
 	{
 		if(m_pImageImage == NULL)
@@ -2487,7 +2489,7 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		UT_DEBUGMSG(("!!!!!!!!!!!!!!!!!!------------------!!!!!!!!!!!\n"));
 	}
 
-	xxx_UT_DEBUGMSG(("SEVIOR: indexAp in Cell Layout %d \n",m_apIndex));
+	UT_DEBUGMSG(("SEVIOR: indexAp in Cell Layout %d \n",m_apIndex));
 	/*
 	  TODO shouldn't we be using PP_evalProperty like
 	  the blockLayout does?
@@ -2548,7 +2550,7 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		break;
 
 	}
-	defaultOffset = "0.01in";
+	defaultOffset = "0.03in";
 
 	static UT_sint32 idefaultOffsetLogicalUnits =  UT_convertToLogicalUnits("0.01in");
 	static double idefaultOffsetDimensionless =  UT_convertDimensionless("0.01in");
@@ -2686,6 +2688,17 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 
 	s_border_properties_cell (pszBorderColor, pszBorderStyle, pszBorderWidth, pszColor, m_lineTop,pTL->getTopStyle());
 
+	const char* pszVertAlign = NULL;
+	pSectionAP->getProperty("vert-align", (const gchar *&)pszVertAlign);
+	if(pszVertAlign && pszVertAlign[0])
+	{
+		m_iVertAlign = atoi(pszVertAlign);
+	}
+	else
+	{
+		m_iVertAlign = 0;
+	}
+
 
 	/* cell fill
 	 */
