@@ -397,11 +397,23 @@ void fp_VerticalContainer::getOffsets(fp_ContainerObject* pContainer, UT_sint32&
 					my_yoff = my_yoff + pVCon->getY() -iycon;
 				}
 			}
-			if(pVCon->getContainer()->getContainerType() == FP_CONTAINER_CELL)
+			if(pVCon && pVCon->getContainer() && (pVCon->getContainer()->getContainerType() == FP_CONTAINER_CELL))
 			{
 				pContainer = static_cast<fp_Container *>(pVCon);
 				xxx_UT_DEBUGMSG(("pContainer set to %p height %d \n",pContainer,pContainer->getHeight()));
 			}
+			else if(pVCon && (pVCon->getContainer() == NULL))
+			{
+			  //
+			  // Just bail out for now
+			  //
+			        return;
+			}
+			if(pVCon == NULL)
+			{
+			        pCon = NULL;
+				break;
+			}
 			pCon = static_cast<fp_Container *>(pVCon);
 		}
 		if(pCon->getContainerType() == FP_CONTAINER_TOC)
@@ -835,6 +847,19 @@ void fp_VerticalContainer::getScreenOffsets(fp_ContainerObject* pContainer,
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 }
 
+
+/*!
+ * remove all contains from this.
+ */
+void fp_VerticalContainer::removeAll(void)
+{
+        UT_sint32 iCount = countCons();
+	UT_sint32 i = 0;
+	for(i=0; i< iCount; i++)
+        {
+	     deleteNthCon(0);
+	}
+}
 /*!
  Remove line from container
  \param pContainer Container
@@ -1628,7 +1653,6 @@ void fp_VerticalContainer::bumpContainers(fp_ContainerObject* pLastContainerToKe
 {
 	UT_sint32 ndx = (NULL == pLastContainerToKeep) ? 0 : (findCon(pLastContainerToKeep)+1);
 	xxx_UT_DEBUGMSG(("!!!---Bump Containers LastToKeep %x Index %d \n",pLastContainerToKeep,ndx));
-
 	UT_ASSERT(ndx >= 0);
 	UT_sint32 i;
 	fp_TOCContainer *pTOC2 = NULL;
@@ -1639,7 +1663,11 @@ void fp_VerticalContainer::bumpContainers(fp_ContainerObject* pLastContainerToKe
 	{
 		for (i=ndx; i< countCons(); i++)
 		{
+			if(i >= countCons())
+			         continue;
 			fp_Container* pContainer = static_cast<fp_Container*>(getNthCon(i));
+			if(pContainer == NULL)
+			        continue;
 			pContainer->clearScreen();
 //
 // Experimental code: FIXME: Might remove after a while - check
@@ -1673,7 +1701,11 @@ void fp_VerticalContainer::bumpContainers(fp_ContainerObject* pLastContainerToKe
 		for (i=countCons() - 1; i >= ndx; i--)
 		{
 			bTOC = false;
+			if(i >= countCons())
+			         continue;
 			fp_Container* pContainer = static_cast<fp_Container*>(getNthCon(i));
+			if(pContainer == NULL)
+			        continue;
 			xxx_UT_DEBUGMSG(("clearScreen on %x in bumpContainers \n",pContainer));
 			pContainer->clearScreen();
 //
@@ -1900,6 +1932,17 @@ void fp_Column::layout(void)
 	fp_Container *pPrevContainer = NULL;
 	UT_sint32 i  = 0;
 	//
+	// First calculate the border widths
+	//
+	for(i=0; i< countCons();i++)
+	{
+		pContainer = static_cast<fp_Container*>(getNthCon(i));
+		if(pContainer->getContainerType() == FP_CONTAINER_LINE)
+		{
+		    static_cast<fp_Line *>(pContainer)->calcBorderThickness();
+		}
+	}
+	//
 	// RedrawHeight makes sure we redraw from whereever a line
 	// changes position.
 	//
@@ -1926,7 +1969,7 @@ void fp_Column::layout(void)
 // Handle case of lines broken around a positioned object with text wrap on
 //
 			fp_Line * pLine = static_cast<fp_Line *>(pContainer);
-			xxx_UT_DEBUGMSG(("Line %x X %d Y %d MaxWidth %d Width %d \n",pLine,pLine->getX(),pLine->getY(),pLine->getMaxWidth(),pLine->getWidth()));
+			xxx_UT_DEBUGMSG(("Line %x X %d Y %d MaxWidth %d Width %d Height %d \n",pLine,pLine->getX(),pLine->getY(),pLine->getMaxWidth(),pLine->getWidth(),pLine->getHeight()));
 			if(pLine->isWrapped())
 			{
 				addWrappedLine(pLine);
@@ -1957,7 +2000,7 @@ void fp_Column::layout(void)
 			  m_iRedrawHeight = pContainer->getY();
 
 		}
-		xxx_UT_DEBUGMSG(("Layout: container %d setY %d \n",i,iY));
+		xxx_UT_DEBUGMSG(("Layout: container %d Height %d setY %d \n",i,iY));
 //
 // fxime comeback and re-evaluate this
 //		UT_ASSERT(iY>=0);
@@ -2016,6 +2059,7 @@ void fp_Column::layout(void)
 			iContainerHeight = pTOC->getHeight();
 		}
 		UT_sint32 iContainerMarginAfter = pContainer->getMarginAfter();
+		xxx_UT_DEBUGMSG(("Layout: container %d Height %d Margin %d setY %d \n",i,iContainerHeight,iContainerMarginAfter,iY));
 		//	UT_ASSERT(iContainerHeight > 0);
 		// Update height of previous line now we know the gap between
 		// it and the current line.
@@ -2099,6 +2143,49 @@ void fp_Column::layout(void)
 	}
 }
 
+bool fp_Column::hasEmptySpaceAtBottom(void)
+{
+        if(countCons() == 0)
+	    return false;
+        UT_sint32 iDiff = getMaxHeight() - getHeight();
+	fp_Container * pLast = static_cast<fp_Container *>(getNthCon(countCons()-1));
+	if(pLast->getContainerType() != FP_CONTAINER_LINE)
+	    return false;
+	fp_Line * pLLast = static_cast<fp_Line *>(pLast);
+	if(pLLast->getContainer()->getContainerType() == FP_CONTAINER_ENDNOTE)
+	    return false;
+	if(pLLast->containsForcedColumnBreak() || pLLast->containsForcedPageBreak())
+	    return false;
+	fp_Container * pNext = pLast->getNextContainerInSection();
+	if(pNext == NULL)
+	  return false;
+	if(pNext->getContainerType() != FP_CONTAINER_LINE)
+	  return false;
+	if(pNext->getContainerType() == FP_CONTAINER_ENDNOTE)
+	    return false;
+	if(pNext->getContainer() == NULL)
+	    return false;
+	if(pNext->getContainer()->getContainerType() == FP_CONTAINER_ENDNOTE)
+	    return false;
+	fp_Line * pNLine = static_cast<fp_Line *>(pNext);
+	if(pNLine->containsFootnoteReference())
+	{
+	  //
+	  // Just bail out for now. Later we can add up the height of the 
+	  // footnotes
+	  //
+	  return false;
+	}
+
+	UT_sint32 iHeight = pNLine->getHeight();
+	if(1.3*static_cast<float>(iHeight) < static_cast<float>(iDiff))
+	{
+	  UT_DEBUGMSG((" height %d iDiff %d pNLine %p \n",iHeight,iDiff,pNLine));
+	     return true;
+	}
+	return false;
+}
+
 UT_sint32 fp_Column::getMaxHeight(void) const
 {
 	const fp_VerticalContainer * pVC = static_cast<const fp_VerticalContainer *>(this);
