@@ -209,6 +209,56 @@ void fp_Container::setMyBrokenContainer(fp_Container * pMyBroken)
 	}
 }
 
+void fp_Container::drawLine(const PP_PropertyMap::Line & style,
+				     UT_sint32 left, UT_sint32 top, 
+				     UT_sint32 right, UT_sint32 bot,
+				     GR_Graphics * pGr)
+{
+	if (style.m_t_linestyle == PP_PropertyMap::linestyle_none &&
+		!pGr->queryProperties(GR_Graphics::DGP_SCREEN))
+		return; // do not draw the dotted line when printing	
+	
+	GR_Graphics::JoinStyle js = GR_Graphics::JOIN_MITER;
+	GR_Graphics::CapStyle  cs = GR_Graphics::CAP_PROJECTING;
+
+	switch (style.m_t_linestyle)
+	{
+		case PP_PropertyMap::linestyle_none:
+			pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_DOTTED);
+			break;
+		case PP_PropertyMap::linestyle_dotted:
+			pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_DOTTED);
+			break;
+		case PP_PropertyMap::linestyle_dashed:
+			pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_ON_OFF_DASH);
+			break;
+		case PP_PropertyMap::linestyle_solid:
+			pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_SOLID);
+			break;
+		default: // do nothing; shouldn't happen
+			break;
+	}
+	UT_sint32 dth = style.m_thickness/2;
+	pGr->setLineWidth (static_cast<UT_sint32>(style.m_thickness));
+	if (style.m_t_linestyle == PP_PropertyMap::linestyle_none)
+	{
+	        pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_SOLID);
+		return;
+	}
+	else
+	{
+		pGr->setColor (style.m_color);
+	}
+
+	xxx_UT_DEBUGMSG(("_drawLine: top %d bot %d \n",top,bot));
+
+	GR_Painter painter(pGr);
+
+	painter.drawLine (left, top, right, bot);
+	pGr->setLineProperties (pGr->tlu(1), js, cs, GR_Graphics::LINE_SOLID);
+}
+
+
 void fp_Container::setNext(fp_ContainerObject * pNext)
 {
   m_pNext = pNext;
@@ -537,7 +587,8 @@ fg_FillType::fg_FillType(fg_FillType *pParent, fp_ContainerObject * pContainer,
 	m_iWidth(0),
 	m_iHeight(0),
 	m_pDocImage(NULL),
-	m_pDocGraphic(NULL)
+	m_pDocGraphic(NULL),
+	m_bIgnoreLineLevel(false)
 {
 }
 
@@ -555,6 +606,13 @@ void  fg_FillType::setParent(fg_FillType * pParent)
 	m_pParent = pParent;
 }
 
+/*!
+ *
+ */
+void  fg_FillType::setIgnoreLineLevel(bool b)
+{
+        m_bIgnoreLineLevel = b;
+}
 /*!
  * set this class to have a solid color fill
  */
@@ -908,8 +966,50 @@ void fg_FillType::Fill(GR_Graphics * pG, UT_sint32 & srcX, UT_sint32 & srcY, UT_
 			    m_pDocImage = getParent()->m_pDocImage;
 		}
 	}
+	if(m_pContainer && (m_pContainer->getContainerType() == FP_CONTAINER_LINE))
+	{
+	    fp_Line * pLine = static_cast<fp_Line *>(m_pContainer);
+	    UT_sint32 left,right = 0;
+	    pLine->getAbsLeftRight(left,right);
+	    if(x < left)
+	    {
+	      UT_DEBUGMSG(("Line x fill outside bounds!! x %d left %d \n",x,left));
+	      // UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+	      x= left;
+	    }
+	    if((x + width) > right)
+	    {
+	      UT_DEBUGMSG(("Line right fill outside bounds!! r %d right %d \n",x+width,left));
+	      // UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+	      width = right -x;
+	    }
+	    if(m_bIgnoreLineLevel && getParent() && m_pContainer)
+	    {
+		UT_sint32 newX = srcX + (m_pContainer->getX());
+		UT_sint32 newY = srcY + (m_pContainer->getY());
+		getParent()->Fill(pG,newX,newY,x,y,width,height);
+		return;
+	    }
+	}
 	if(m_pContainer && (m_pContainer->getContainerType() == FP_CONTAINER_RUN))
 	{
+	        fp_Line * pLine = static_cast<fp_Run *>(m_pContainer)->getLine();
+		if(pLine == NULL)
+		  return;
+	        UT_sint32 left,right = 0;
+	        pLine->getAbsLeftRight(left,right);
+	        if(x < left)
+		{
+		  xxx_UT_DEBUGMSG(("Run x fill outside bounds!! x %d left %d \n",x,left));
+		  // UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		  x= left;
+		}
+	        if((x + width) > right)
+		{
+		  xxx_UT_DEBUGMSG(("run right fill outside bounds!! r %d right %d \n",x+width,left));
+		  // UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		  width = right -x;
+		}
 		if(m_iGraphicTick != m_pDocLayout->getGraphicTick() )
 		{
 			m_iGraphicTick = m_pDocLayout->getGraphicTick();
