@@ -247,6 +247,8 @@ public:
 	bool                isInNestedTable(void);
 	bool                containsNestedTables(void);
 	bool                isRepeated(void) const;
+	void                setVertAlign(UT_sint32 i) { m_iVertAlign = i; }
+	void doVertAlign(void);
 #ifdef FMT_TEST
 	void				__dump(FILE * fp) const;
 #endif
@@ -254,8 +256,6 @@ public:
 private:
 		
 	void                _clear(fp_TableContainer * pBroke);
-	void				_drawLine(const PP_PropertyMap::Line & style,
-								  UT_sint32 left, UT_sint32 top, UT_sint32 right, UT_sint32 bot,GR_Graphics * pG);
 	void				_getBrokenRect(fp_TableContainer * pBroke, fp_Page* &pPage, UT_Rect &bRec, GR_Graphics * pG);
 		
 //
@@ -341,6 +341,10 @@ private:
 	bool                   m_bDirty;
 
 	bool                   m_bIsRepeated;
+
+// Vertical alignment property
+
+	UT_sint32	m_iVertAlign;
 };
 
 class ABI_EXPORT fp_TableContainer : public fp_VerticalContainer
@@ -545,6 +549,6 @@ private:
 	fp_CellContainer *  m_pLastBrokenCell;
 	bool                m_bRecursiveClear;
 	UT_sint32           m_iAdditionalMarginAfter;
- };
+};
 
 #endif /* TABLECONTAINER_H */
