@@ -61,7 +61,11 @@ class fl_BlockLayout;
 class fp_Run;
 class UT_UTF8String;
 class pp_Author;
+class PD_DocumentRDF;
+class AP_StatusBar;
 
+#include <boost/shared_ptr.hpp>
+typedef boost::shared_ptr<PD_DocumentRDF> PD_DocumentRDFHandle;
 
 #ifdef PT_TEST
 #include "ut_test.h"
@@ -215,7 +219,8 @@ public:
 	UT_Error		importFile(GsfInput *input, int ieft, bool markClean = false, bool bImportStylesFirst = true,
 							   const char * impProps = NULL);
 	virtual UT_Error		importStyles(const char * szFilename, int ieft, bool bDocProps = false);
-
+	AP_StatusBar *          getStatusBar(void);
+	void                    updateStatus(void);
 	virtual UT_Error		newDocument(void);
 
 	UT_Error  		saveAs(GsfOutput * output, int ieft, bool cpy = false, const char * expProps = NULL);
@@ -612,6 +617,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 	pt_PieceTable *			getPieceTable(void) const
 		{ return m_pPieceTable; }
+    PD_DocumentRDFHandle    getDocumentRDF(void) const;
 #ifdef PT_TEST
 	void					__dump(FILE * fp) const;
 	//! Pointer to last instatiated PD_Document. Used for debugging.
@@ -793,6 +799,7 @@ private:
 private:
 	bool					m_ballowListUpdates;
 	pt_PieceTable *			m_pPieceTable;
+    PD_DocumentRDFHandle    m_hDocumentRDF;
 	UT_GenericVector<PL_Listener *> m_vecListeners;
 	UT_GenericVector<fl_AutoNum *> m_vecLists;
 	bool                    m_bHasListStopped;
@@ -843,6 +850,7 @@ private:
 	UT_sint32               m_iLastAuthorInt;
 	UT_GenericVector<ImagePage *> m_pPendingImagePage;
 	UT_GenericVector<TextboxPage *> m_pPendingTextboxPage;
+	UT_sint32               m_iStruxCount;
 };
 
 #endif /* PD_DOCUMENT_H */
