@@ -24,10 +24,13 @@
 #include <stdio.h>
 #include "ut_types.h"
 #include "pt_Types.h"
+#include "pf_Fragments.h"
+
 class pt_PieceTable;
 class PX_ChangeRecord;
 class fd_Field;
 
+
 /*!
  pf_Frag represents a fragment of the document.  This may be text
  (pf_Frag_Text), an inline object such as an image (pf_Frag_Object),
@@ -41,6 +44,7 @@ class fd_Field;
 
 class ABI_EXPORT pf_Frag
 {
+  friend class            pf_Fragments;
 public:
 	typedef enum _PFType { PFT_Text = 0, PFT_Object, PFT_Strux, PFT_EndOfDoc, PFT_FmtMark } PFType;
 
@@ -48,17 +52,22 @@ public:
 	virtual ~pf_Frag();
 
 	inline PFType			getType(void) const		{ return m_type; }
-	inline pf_Frag *		getNext(void) const		{ return m_next; }
-	inline pf_Frag *		getPrev(void) const		{ return m_prev; }
-
-	pf_Frag *				setNext(pf_Frag * pNext);
-	pf_Frag *				setPrev(pf_Frag * pPrev);
+	pf_Frag *                       getNext(void) const;
+	pf_Frag *                       getPrev(void) const;
 
 	inline UT_uint32		getLength(void) const	{ return m_length; }
+	inline void                     zero(void)
+	{ m_length = 0;}
+
 	pt_PieceTable *			getPieceTable(void) const { return m_pPieceTable;}
 	fd_Field *				getField(void) const;
-	PT_DocPosition          getPos(void) const { return m_docPos;}
-	void                    setPos(PT_DocPosition pos) const { m_docPos = pos;}
+	PT_DocPosition          getPos(void) const;
+	void                    lengthChanged(UT_sint32 delta);
+	PT_DocPosition          getLeftTreeLength(void) const   { return m_leftTreeLength; }
+	void                    setLeftTreeLength(PT_DocPosition length) const { m_leftTreeLength = length;}
+
+	/* We need the following function to accumulate left tree length */
+	void                    accLeftTreeLength(PT_DocPosition length);
 
 	inline PT_AttrPropIndex	getIndexAP(void) const {return m_indexAP;}
 	virtual void			setIndexAP(PT_AttrPropIndex indexNewAP)	{m_indexAP = indexNewAP;}
@@ -84,7 +93,8 @@ public:
 	
 #ifdef PT_TEST
 	virtual void			__dump(FILE * fp) const;
-#endif
+#endif	
+
 
 protected:
 /*!
@@ -111,17 +121,21 @@ protected:
 	virtual bool            _isContentEqual(const pf_Frag & /*f2*/) const {return true;}
 	
 	PFType					m_type;
-	UT_uint32				m_length;	/* in PT_DocPosition-space */
-	pf_Frag *				m_next;
-	pf_Frag *				m_prev;
 	
-    fd_Field *              m_pField;
+	fd_Field *              m_pField;
 	pt_PieceTable *			m_pPieceTable;
 	PT_AttrPropIndex		m_indexAP;
 
+	/* in PT_DocPosition-space - gives length of this fragment */ 
+	UT_uint32				m_length;	
+
 private:
-	mutable PT_DocPosition  m_docPos;
+        void                    _setNode(pf_Fragments::Node * pNode);
+	pf_Fragments::Node *    _getNode(void) const;
+	/* In PT_DocPosition space - specifies size of left subtree */
+	mutable UT_sint32       m_leftTreeLength;   
 	UT_uint32               m_iXID;
+	pf_Fragments::Node *    m_pMyNode;
 };
 
 #endif /* PF_FRAG_H */
