@@ -124,6 +124,24 @@ bool pt_PieceTable::deleteFragNoUpdate(pf_Frag * pf)
 	return true;
 }
 
+/*!
+ * Itterate through the document to calculate the document size
+ * Don't call this in production code. This is used only for recovery and 
+ * testing purposes
+ */
+UT_sint32 pt_PieceTable::calcDocsize(void)
+{
+	UT_sint32 size = 0;
+	pf_Frag * pf = getFragments().getFirst();
+	while(pf && (pf->getType() !=  pf_Frag::PFT_EndOfDoc))
+	{
+		size += static_cast<UT_sint32>(pf->getLength());
+		pf = pf->getNext();
+	}
+	UT_ASSERT(pf->getType() ==  pf_Frag::PFT_EndOfDoc);
+	return size;
+}
+
 bool pt_PieceTable::createAndSendDocPropCR( const gchar ** pAtts, const gchar ** pProps)
 {
 	PT_AttrPropIndex indexAP = 0;
@@ -692,13 +710,6 @@ bool pt_PieceTable::getBounds(bool bEnd, PT_DocPosition & docPos) const
 	}
 	else
 	{
-		// NOTE: this gets called for every cursor motion
-		// TODO: be more efficient & cache the doc length
-		// Sevior I did this 6/6/2001
-		if(m_fragments.areFragsDirty())
-		{
-			m_fragments.cleanFrags();
-		}
 		docPos = m_fragments.getLast()->getPos()+m_fragments.getLast()->getLength();
 	}
 	return res;
@@ -775,8 +786,6 @@ void pt_PieceTable::_realDeleteHdrFtrStrux(pf_Frag_Strux * pfs)
 
 PT_DocPosition pt_PieceTable::getFragPosition(const pf_Frag * pfToFind) const
 {
-	if(m_fragments.areFragsDirty())
-		m_fragments.cleanFrags();
 	return  pfToFind->getPos();
 }
 
@@ -803,7 +812,6 @@ bool pt_PieceTable::getFragFromPosition(PT_DocPosition docPos,
 			*pFragOffset = docPos - pfLast->getPos();
 		*ppf = pfLast;       
 		return true;
-		xxx_UT_DEBUGMSG(("SEVIOR: I found frag %d \n",getFragNumber(pfLast)));
 	}
 
 	UT_return_val_if_fail (pfLast,false);
@@ -826,7 +834,6 @@ bool pt_PieceTable::getFragFromPosition(PT_DocPosition docPos,
 //  			// in this loop -- rather we want the thing just past it.
 
 //  			UT_ASSERT(pf->getType() != pf_Frag::PFT_FmtMark);
-//  			UT_DEBUGMSG(("SEVIOR: Jeff finds frag %d at Pos %d \n",getFragNumber(pf),docPos));
 
 //  			return true;
 //  		}
@@ -849,7 +856,6 @@ bool pt_PieceTable::getFragFromPosition(PT_DocPosition docPos,
 //  	*ppf = pfLast;
 //  	if (pFragOffset)
 //  		*pFragOffset = docPos - sum;
-//  	UT_DEBUGMSG(("SEVIOR: Jeff finds Last frag Number %d at Pos %d \n",getFragNumber(pf),docPos));
 
 
 //  	return true;
@@ -883,6 +889,10 @@ bool pt_PieceTable::getFragsFromPositions(PT_DocPosition dPos1, PT_DocPosition d
 		if (pf->getType() == pf_Frag::PFT_EndOfDoc)
 			break;						// TODO if we haven't quite reached dPos2, we should probably complain...
 		pf = pf->getNext();
+		if(pf == NULL)
+		{
+			return false;
+		}
 		length = pf->getLength();
 	}
 
@@ -1014,7 +1024,7 @@ bool pt_PieceTable::_getStruxFromPosition(PT_DocPosition docPos,
 	xxx_UT_DEBUGMSG(("countEndNotes final %d \n",countEndFootnotes));
   	pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *> (pfFirst);
   	*ppfs = pfs;
-    return true;
+	return pfs != NULL;
 }
 
 bool pt_PieceTable::_getStruxOfTypeFromPosition(PT_DocPosition dpos,
