@@ -342,7 +342,6 @@ public:
 	bool                    isFootnote(pf_Frag * pf) const;
 	
 	void					clearIfAtFmtMark(PT_DocPosition dpos);
-	UT_uint32               getFragNumber(pf_Frag * pFrag) const {return m_fragments.getFragNumber(pFrag);}
     pt_VarSet &             getVarSet(void) {return m_varset;};
     pf_Fragments &          getFragments(void) {return m_fragments;};
 
@@ -356,6 +355,7 @@ public:
 	UT_uint32               getTopXID() const {return m_iXID;}
 	void                    setXIDThreshold(UT_uint32 i){m_iXID = i;}
 	void                    fixMissingXIDs();
+	UT_sint32               calcDocsize(void);
 	void                    setCRNumber(UT_sint32 iCRNumber)
 	{ m_iCurCRNumber = iCRNumber;}
 #ifdef PT_TEST
