@@ -460,6 +460,10 @@ bool pt_VarSet::mergeAP(PTChangeFmt ptc, PT_AttrPropIndex apiOld,
 	}
 }
 
+/*!
+ * This method takes consumes pAP, do not attempt to access pAP after 
+calling this method.
+*/
 bool pt_VarSet::addIfUniqueAP(PP_AttrProp * pAP, PT_AttrPropIndex * papi)
 {
 	// Add the AP to our tables iff it is unique.
@@ -469,7 +473,7 @@ bool pt_VarSet::addIfUniqueAP(PP_AttrProp * pAP, PT_AttrPropIndex * papi)
 	// return false if we have any errors.
 
 	UT_return_val_if_fail (pAP && papi, false);
-	UT_uint32 subscript = 0;
+	UT_sint32 subscript = 0;
 	UT_uint32 table = 0;
 
 	for (table=0; table<2; table++)
