@@ -39,6 +39,7 @@
 #include <signal.h>
 #include <X11/Xlib.h>
 #include <glib.h>
+#include <gsf/gsf-output-memory.h>
 
 #include "ut_debugmsg.h"
 #include "ut_path.h"
@@ -53,6 +54,7 @@
 #include "ap_UnixFrame.h"
 #include "ap_UnixFrameImpl.h"
 #include "ap_UnixApp.h"
+#include "xap_UnixApp.h"
 
 #ifdef ENABLE_SPELL
   #include "spell_manager.h"
@@ -114,6 +116,7 @@
 #include "xap_UnixDialogHelper.h"
 #include "gr_UnixCairoGraphics.h"
 #include "gr_UnixPangoPixmapGraphics.h"
+#include "ie_exp_DocRangeListener.h"
 
 #ifdef GTK_WIN_POS_CENTER_ALWAYS
 #define WIN_POS GTK_WIN_POS_CENTER_ALWAYS
@@ -219,11 +222,55 @@ AP_UnixApp::loadStringsFromDisk(const char 			* szStringSet,
 			       static_cast<const gchar**>(&szDirectory));
 	UT_return_val_if_fail((szDirectory) && (*szDirectory), NULL);
 
+	UT_String szPathVariant[4];
+	char * p_strbuf = strdup("");
+	char * p_modifier = NULL;
+	int  cur_id = 0;
+	bool three_letters = false; // some have 3!
+
+	if (szStringSet) {
+		FREEP(p_strbuf);
+		p_strbuf = strdup(szStringSet);
+		p_modifier = strrchr(p_strbuf,'@');
+		
+		char t = szStringSet[2];
+		if (t && t!='-' && t!='@' && t!='_') three_letters = true;
+	}
+
+	if (p_modifier) {
+		// fo_BA@xxx.strings
+		szPathVariant[cur_id] = szDirectory;
+		if (szDirectory[strlen(szDirectory)-1]!='/')
+			szPathVariant[cur_id] += "/";
+		szPathVariant[cur_id] += p_strbuf;
+		szPathVariant[cur_id] += ".strings";
+
+		cur_id++;
+
+		// fo@xxx.strings
+		if (szStringSet && strlen(szStringSet) > 2) {
+			szPathVariant[cur_id] = szDirectory;
+			if (szDirectory[strlen(szDirectory)-1]!='/')
+				szPathVariant[cur_id] += "/";
+			szPathVariant[cur_id] += p_strbuf[0];
+			szPathVariant[cur_id] += p_strbuf[1];
+			if (three_letters)
+				szPathVariant[cur_id] += p_strbuf[2];
+			szPathVariant[cur_id] += p_modifier;
+			szPathVariant[cur_id] += ".strings";
+		}
+
+		cur_id++;
+
+		// trim modifier part
+		*p_modifier = 0;
+	}
+	
 	// fo_BA.strings
 	UT_String szPath = szDirectory;
 	if (szDirectory[szPath.size()-1]!='/')
 		szPath += "/";
-	szPath += szStringSet;
+	szPath += p_strbuf;
 	szPath += ".strings";
 
 	// fo.strings
@@ -232,12 +279,27 @@ AP_UnixApp::loadStringsFromDisk(const char 			* szStringSet,
 		szFallbackPath = szDirectory;
 		if (szDirectory[szFallbackPath.size()-1]!='/')
 			szFallbackPath += "/";
-		szFallbackPath += szStringSet[0];
-		szFallbackPath += szStringSet[1];
+		szFallbackPath += p_strbuf[0];
+		szFallbackPath += p_strbuf[1];
+		if (three_letters)
+			szFallbackPath += p_strbuf[2];
 		szFallbackPath += ".strings";
 	}
 
 	AP_DiskStringSet * pDiskStringSet = new AP_DiskStringSet(this);
+
+	FREEP(p_strbuf);
+
+	// trying to load specific strings first
+	for (int i=0; i<cur_id; i++) {
+		if (pDiskStringSet->loadStringsFromDisk(szPathVariant[i].c_str())) {
+			pDiskStringSet->setFallbackStringSet(pDefaultStringSet);
+			UT_DEBUGMSG(("Using [v] StringSet [%s]\n",szPathVariant[i].c_str()));
+			return pDiskStringSet;
+		}
+	}
+
+	// then generic ones
 	if (pDiskStringSet->loadStringsFromDisk(szPath.c_str()))
 	{
 		pDiskStringSet->setFallbackStringSet(pDefaultStringSet);
@@ -275,6 +337,12 @@ bool AP_UnixApp::initialize(bool has_display)
 		  UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
       }
 
+    // COPYPASTA WARNING (ap_Win32App.cpp)
+    // create templates directory
+    UT_String sTemplates = szUserPrivateDirectory;
+    sTemplates += "/templates";
+    s_createDirectoryIfNecessary(sTemplates.c_str());
+
     // load the preferences.
     
     m_prefs = new AP_UnixPrefs();
@@ -309,7 +377,8 @@ bool AP_UnixApp::initialize(bool has_display)
 		if (m_pStringSet == NULL) 
 		{
 			const char *szFallbackStringSet = UT_getFallBackStringSetLocale(szStringSet);
-			m_pStringSet = loadStringsFromDisk(szFallbackStringSet, pBuiltinStringSet);
+			if (szFallbackStringSet)
+				m_pStringSet = loadStringsFromDisk(szFallbackStringSet, pBuiltinStringSet);
 		}
 
 		// load the builtin string set
@@ -324,7 +393,6 @@ bool AP_UnixApp::initialize(bool has_display)
 	if (has_display) {	   
 		m_pClipboard = new AP_UnixClipboard(this);
 		UT_ASSERT(m_pClipboard);
-		m_pClipboard->initialize();
 
 		abi_stock_init ();
     }
@@ -379,6 +447,11 @@ bool AP_UnixApp::initialize(bool has_display)
 	bool bFound = getPrefsValueBool(XAP_PREF_KEY_AutoLoadPlugins,&bLoadPlugins);
 	if(bLoadPlugins || !bFound)
 		loadAllPlugins();
+	//
+	// Now all the plugins are loaded we can initialize the clipboard
+	//
+	if(m_pClipboard)
+		m_pClipboard->initialize();
 
     return true;
 }
@@ -411,6 +484,7 @@ bool AP_UnixApp::shutdown(void)
 	{
 		if (m_prefs->getAutoSavePrefs())
 			m_prefs->savePrefsFile();
+		XAP_UnixApp::shutdown();
 	}
     return true;
 }
@@ -505,6 +579,7 @@ void AP_UnixApp::copyToClipboard(PD_DocumentRange * pDocRange, bool bUseClipboar
     UT_ByteBuf bufHTML4;
     UT_ByteBuf bufXHTML;
     UT_ByteBuf bufTEXT;
+    UT_ByteBuf bufODT;
 
     // create RTF buffer to put on the clipboard
 		
@@ -535,6 +610,29 @@ void AP_UnixApp::copyToClipboard(PD_DocumentRange * pDocRange, bool bUseClipboar
 			DELETEP(pExpHtml);
 		}
 
+	// Look to see if the ODT plugin is loaded
+
+	IEFileType ftODT = IE_Exp::fileTypeForMimetype("application/vnd.oasis.opendocument.text");
+	bool bExpODT = false;
+	if(ftODT != IEFT_Unknown)
+	{
+		// ODT plugin is present construct an exporter
+		//
+		IE_Exp * pODT = NULL;
+		IEFileType genIEFT = IEFT_Unknown;
+		GsfOutput * outBuf =  gsf_output_memory_new();
+		UT_Error err = IE_Exp::constructExporter(pDocRange->m_pDoc,outBuf,
+												 ftODT,&pODT,& genIEFT);
+		if(pODT && (genIEFT == ftODT))
+		{
+			//												 
+			// Copy to the buffer
+			//
+			err = pODT->copyToBuffer(pDocRange, &bufODT);
+			bExpODT = (err == UT_OK);
+		}
+	}
+
     // create UTF-8 text buffer to put on the clipboard
 		
     IE_Exp_Text * pExpText = new IE_Exp_Text(pDocRange->m_pDoc, "UTF-8");
@@ -562,6 +660,8 @@ void AP_UnixApp::copyToClipboard(PD_DocumentRange * pDocRange, bool bUseClipboar
 		m_pClipboard->addHtmlData (target, bufXHTML.getPointer (0), bufXHTML.getLength (), true);
 	if (bufHTML4.getLength () > 0)
 		m_pClipboard->addHtmlData (target, bufHTML4.getPointer (0), bufHTML4.getLength (), false);
+	if (bExpODT && bufODT.getLength () > 0)
+		m_pClipboard->addODTData (target, bufODT.getPointer (0), bufODT.getLength ());
 	if (bufTEXT.getLength () > 0)
 		m_pClipboard->addTextData (target, bufTEXT.getPointer (0), bufTEXT.getLength ());
 
@@ -625,7 +725,10 @@ void AP_UnixApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool bUseClipb
 		UT_DEBUGMSG(("PasteFromClipboard: did not find anything to paste.\n"));
 		return;
     }
-
+    if (AP_UnixClipboard::isDynamicTag (szFormatFound))
+	{
+		UT_DEBUGMSG(("Dynamic Format Found = %s \n",szFormatFound));
+	}
     if (AP_UnixClipboard::isRichTextTag(szFormatFound))
     {
 		IE_Imp_RTF * pImpRTF = new IE_Imp_RTF(pDocRange->m_pDoc);
@@ -1106,7 +1209,7 @@ GR_Graphics * AP_UnixApp::newDefaultScreenGraphics() const
 	GtkWidget * da = pFI->getDrawingArea();
 	UT_return_val_if_fail( da, NULL );
 	
-	GR_UnixCairoAllocInfo ai(da->window);
+	GR_UnixCairoAllocInfo ai(da);
 	return XAP_App::getApp()->newGraphics(ai);
 }
 
