@@ -301,13 +301,8 @@ AP_UnixDialog_Goto::onJumpClicked ()
 	if (!text)
 		return;		
 
-	UT_uint32 len = strlen (text);
-	UT_UCSChar *number = (UT_UCSChar *) g_try_malloc (sizeof (UT_UCSChar) * (len + 1));
-	UT_UCS4_strcpy_utf8_char (number, text);
-	UT_DEBUGMSG (("ROB: onJumpClicked () gotoTarget () target='%d' number='%s'\n", m_JumpTarget, text));
-	getView()->gotoTarget (m_JumpTarget, number);
-
-	FREEP (number);
+	performGoto(m_JumpTarget, text);
+	
 	if (freeText && text) {
 		g_free ((gchar *)text);
 	}
@@ -436,8 +431,8 @@ AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/)
 	// localise	
 	// const XAP_StringSet * pSS = m_pApp->getStringSet ();
 	/* FIXME jump targets localised in xp land, make sure they work for non ascii characters */
-	gchar **targets = getJumpTargets ();
-	gchar *text = NULL;
+	const gchar **targets = getJumpTargets ();
+	const gchar *text = NULL;
 	if ((text = targets[AP_JUMPTARGET_PAGE]) != NULL)
 		gtk_label_set_text (GTK_LABEL (m_lbPage), text);
 	if ((text = targets[AP_JUMPTARGET_LINE]) != NULL)
