@@ -82,6 +82,7 @@
 #include "ut_Win32OS.h"
 #include "ut_Win32Idle.h"
 #include "ut_Language.h"
+#include "ut_Win32LocaleString.h"
 
 #include "ie_impexp_Register.h"
 
@@ -126,8 +127,11 @@ AP_Win32App::~AP_Win32App(void)
 static bool s_createDirectoryIfNecessary(const char * szDir)
 {
 	struct _stat statbuf;
+	UT_Win32LocaleString str;
 	
-	if (_stat(szDir,&statbuf) == 0)								// if it exists
+	str.fromUTF8(szDir);
+
+	if (_wstat(str.c_str(),&statbuf) == 0)								// if it exists
 	{
 		if ( (statbuf.st_mode & _S_IFDIR) == _S_IFDIR )			// and is a directory
 			return true;
@@ -136,7 +140,7 @@ static bool s_createDirectoryIfNecessary(const char * szDir)
 		return false;
 	}
 
-	if (CreateDirectory(szDir,NULL))
+	if (CreateDirectoryW(str.c_str(),NULL))
 		return true;
 
 	UT_DEBUGMSG(("Could not create Directory [%s].\n",szDir));
@@ -153,6 +157,11 @@ bool AP_Win32App::initialize(void)
 
 	UT_return_val_if_fail (bVerified, false);
 
+	// create templates directory
+	UT_String sTemplates = szUserPrivateDirectory;
+	sTemplates += "/templates";
+	s_createDirectoryIfNecessary(sTemplates.c_str());
+
 	// load the preferences.
 	
 	m_prefs = new AP_Win32Prefs();
@@ -217,7 +226,7 @@ bool AP_Win32App::initialize(void)
 			{
 				pDiskStringSet->setFallbackStringSet(m_pStringSet);
 				m_pStringSet = pDiskStringSet;
-                UT_Language_updateLanguageNames();
+				UT_Language_updateLanguageNames();
 				UT_DEBUGMSG(("Using StringSet [%s]\n",szPathname));
 			}
 			else
@@ -293,49 +302,28 @@ bool AP_Win32App::initialize(void)
 	// Check for necessary DLLs now that we can do localized error messages
 	//////////////////////////////////////////////////////////////////
 
-#if 0 /* re-enable once we use unicows again */
-	// Ensure that we have Unicows dll
-	if (!UT_IsWinNT())
-	{
-		HMODULE hModule = LoadLibrary("unicows.dll");
-		
-		if (!hModule)
-		{
-			UT_String sErr(UT_String_sprintf(m_pStringSet->getValue(AP_STRING_ID_WINDOWS_NEED_UNICOWS),
-											 "Unicows"));
-
-			MessageBox(NULL, sErr.c_str(), NULL, MB_OK);
-
-			bSuccess = false;
-		}
-		else
-			FreeLibrary(hModule);
-	}
-#endif
-
 	// Ensure that common control DLL is loaded
-	HINSTANCE hinstCC = LoadLibrary("comctl32.dll");
+	HINSTANCE hinstCC = LoadLibraryW(L"comctl32.dll");
 	UT_return_val_if_fail (hinstCC, false);
 	InitCommonControlsEx_fn  pInitCommonControlsEx = NULL;
 	if( hinstCC != NULL )
-		pInitCommonControlsEx = (InitCommonControlsEx_fn)GetProcAddress( hinstCC, "InitCommonControlsEx" );
+		pInitCommonControlsEx = (InitCommonControlsEx_fn)GetProcAddress( hinstCC, "InitCommonControlsEx");
 	if( pInitCommonControlsEx != NULL )
 	{
 		INITCOMMONCONTROLSEX icex;
 		icex.dwSize = sizeof(INITCOMMONCONTROLSEX);
 		icex.dwICC = ICC_COOL_CLASSES | ICC_BAR_CLASSES 	// load the rebar and toolbar
 					| ICC_TAB_CLASSES | ICC_UPDOWN_CLASS	// and tab and spin controls
-					;
+					| ICC_STANDARD_CLASSES;
 		pInitCommonControlsEx(&icex);
 	}
 	else
 	{
 		InitCommonControls();
 
-		UT_String sErr(UT_String_sprintf(m_pStringSet->getValue(AP_STRING_ID_WINDOWS_COMCTL_WARNING),
-										 "Unicows"));
-
-		MessageBox(NULL, sErr.c_str(), NULL, MB_OK);
+		UT_Win32LocaleString err;
+		err.fromUTF8 (m_pStringSet->getValue(AP_STRING_ID_WINDOWS_COMCTL_WARNING));		
+		MessageBoxW(NULL, err.c_str(), NULL, MB_OK);
 	}
 
 	//////////////////////////////////////////////////////////////////
@@ -351,48 +339,51 @@ bool AP_Win32App::initialize(void)
 
 	if(bLoadPlugins || !bFound)
 	{
-		char szPath[PATH_MAX];
-		char szPlugin[PATH_MAX];
+		WCHAR szPath[PATH_MAX];
+		WCHAR szPlugin[PATH_MAX];
 		_getExeDir( szPath, PATH_MAX);
 #ifdef _MSC_VER
-		strcat(szPath, "..\\plugins\\*.dll");
+		lstrcatW(szPath, L"..\\plugins\\*.dll");
 #else
-		strcat(szPath, "..\\lib\\" PACKAGE "-" ABIWORD_SERIES "\\plugins\\*.dll");
+#define ABI_WIDE_STRING(t) L ## t
+		lstrcatW(szPath, ABI_WIDE_STRING("..\\lib\\" PACKAGE L"-" ABIWORD_SERIES L"\\plugins\\*.dll"));
 #endif
 
-	    struct _finddata_t cfile;
-		long findtag = _findfirst( szPath, &cfile );
-		if( findtag != -1 )
+		WIN32_FIND_DATAW cfile;
+		HANDLE findtag = FindFirstFileW( szPath, &cfile );
+		if( findtag != INVALID_HANDLE_VALUE )
 		{
 			do
 			{	
 				_getExeDir( szPlugin, PATH_MAX );
 #ifdef _MSC_VER
-				strcat( szPlugin, "..\\plugins\\" );
+				lstrcatW( szPlugin, L"..\\plugins\\" );
 #else
-				strcat( szPlugin, "..\\lib\\" PACKAGE "-" ABIWORD_SERIES "\\plugins\\" );
+				lstrcatW( szPlugin, ABI_WIDE_STRING("..\\lib\\" PACKAGE L"-" ABIWORD_SERIES L"\\plugins\\" ));
 #endif
-				strcat( szPlugin, cfile.name );
-				XAP_ModuleManager::instance().loadModule( szPlugin );
-			} while( _findnext( findtag, &cfile ) == 0 );
+				lstrcatW( szPlugin, cfile.cFileName );
+				XAP_ModuleManager::instance().loadModule( getUTF8String(szPlugin) );
+			} while( FindNextFileW ( findtag, &cfile ) );
+			FindClose( findtag );
 		}
-		_findclose( findtag );
 
 		UT_String pluginName( getUserPrivateDirectory() ); 
 		UT_String pluginDir( getUserPrivateDirectory() );
 		pluginDir += "\\AbiWord\\plugins\\*.dll";
-		findtag = _findfirst( pluginDir.c_str(), &cfile );
-		if( findtag != -1 )
+		UT_Win32LocaleString str;
+		str.fromUTF8(pluginDir.c_str());
+		findtag = FindFirstFileW( str.c_str(), &cfile );
+		if( findtag != INVALID_HANDLE_VALUE )
 		{
 			do
 			{	
 				pluginName = getUserPrivateDirectory();
 				pluginName += "\\AbiWord\\plugins\\";
-				pluginName += cfile.name;
+				pluginName += getUTF8String(cfile.cFileName);
 				XAP_ModuleManager::instance().loadModule( pluginName.c_str() );
-			} while( _findnext( findtag, &cfile ) == 0 );
+			} while( FindNextFileW( findtag, &cfile ) );
+			FindClose( findtag );
 		}
-		_findclose( findtag );
 	}
 	return bSuccess;
 }
@@ -460,9 +451,9 @@ HICON AP_Win32App::getIcon(void)
 	UT_DEBUGMSG(("GetIcon(): system metrics [%d %d]\n",sx,sy));
 	
 	if ((sx==32) && (sy==32))
-		return LoadIcon(getInstance(), MAKEINTRESOURCE(AP_RID_ICON_APPLICATION_32));
+		return LoadIconW(getInstance(), MAKEINTRESOURCEW(AP_RID_ICON_APPLICATION_32));
 	else
-		return (HICON) LoadImage(getInstance(), MAKEINTRESOURCE(AP_RID_ICON_APPLICATION_32), IMAGE_ICON, 0,0,0);
+		return (HICON) LoadImageW(getInstance(), MAKEINTRESOURCEW(AP_RID_ICON_APPLICATION_32), IMAGE_ICON, 0,0,0);
 }
 
 HICON AP_Win32App::getSmallIcon(void)
@@ -473,9 +464,9 @@ HICON AP_Win32App::getSmallIcon(void)
 	UT_DEBUGMSG(("GetIcon(): system metrics [%d %d]\n",sx,sy));
 
 	if ((sx==16) && (sy==16))
-		return LoadIcon(getInstance(), MAKEINTRESOURCE(AP_RID_ICON_APPLICATION_16));
+		return LoadIconW(getInstance(), MAKEINTRESOURCEW(AP_RID_ICON_APPLICATION_16));
 	else
-		return (HICON) LoadImage(getInstance(), MAKEINTRESOURCE(AP_RID_ICON_APPLICATION_16), IMAGE_ICON, 0,0,0);
+		return (HICON) LoadImageW(getInstance(), MAKEINTRESOURCEW(AP_RID_ICON_APPLICATION_16), IMAGE_ICON, 0,0,0);
 }
 
 const XAP_StringSet * AP_Win32App::getStringSet(void) const
@@ -493,7 +484,7 @@ void AP_Win32App::_indicateFmtToClipboard(const char * pszFmt) const
 	UT_return_if_fail(m_pClipboard && pszFmt);
 	UINT iFmt = m_pClipboard->convertFormatString(pszFmt);
 
-	SetClipboardData(iFmt, NULL);
+	SetClipboardDataW(iFmt, NULL);
 }
 
 bool AP_Win32App::_cacheClipboardDoc(PD_DocumentRange *pDocRange)
@@ -772,7 +763,7 @@ PBITMAPINFO CreateBitmapInfoStruct(HBITMAP hBmp)
 	WORD    	cClrBits; 
 
 	// Retrieve the bitmap's color format, width, and height. 
-    	if (!GetObject(hBmp, sizeof(BITMAP), (LPSTR)&bmp)) 
+    	if (!GetObjectW(hBmp, sizeof(BITMAP), (LPSTR)&bmp)) 
 		return NULL;
 	
 	if (bmp.bmBitsPixel==16) bmp.bmBitsPixel=24;	// 16 bit BMPs are not supported by all programs
@@ -1085,9 +1076,9 @@ int AP_Win32App::WinMain(const char * szAppName, HINSTANCE hInstance,
 	// TODO: fix Spell dlg so we don't rely on this
 	// ALT:  make it a Preview widget instead
 
-	HINSTANCE hinstRich = LoadLibrary("riched32.dll");
+	HINSTANCE hinstRich = LoadLibraryW(L"riched32.dll");
 	if (!hinstRich)
-		hinstRich = LoadLibrary("riched20.dll");
+		hinstRich = LoadLibraryW(L"riched20.dll");
 	UT_return_val_if_fail (hinstRich, 1);
 	
 	AP_Win32App * pMyWin32App;
@@ -1098,14 +1089,14 @@ int AP_Win32App::WinMain(const char * szAppName, HINSTANCE hInstance,
   
 	
 // We put this in a block to force the destruction of Args in the stack
-{	
+{
+	UT_Win32LocaleString scnv;
+	UT_UTF8String sUTFCmdLine;
+
 	// Load the command line into an XAP_Args class
-#ifdef _MSC_VER	// when using MSVC use already split arguments
-	XAP_Args XArgs = XAP_Args(__argc, __argv);
-#else			// but for other compiles may not be available so use szCmdLine
-	UT_String szNewCmdLine = UT_String_sprintf ( "%s %s", "AbiWord.exe", szCmdLine ) ;
-	XAP_Args XArgs = XAP_Args(szNewCmdLine.c_str());
-#endif
+	scnv.fromLocale(GetCommandLineW());
+	sUTFCmdLine=scnv.utf8_str();
+	XAP_Args XArgs = XAP_Args(sUTFCmdLine.utf8_str());
 
 	// Step 1: Initialize our application.
 	pMyWin32App = new AP_Win32App(hInstance, szAppName);
@@ -1170,7 +1161,7 @@ try
 		}	
 
 		// do dispatch loop
-		while(UT_GetMessage(&msg, NULL, 0, 0, m_bForceAnsi))
+		while(UT_GetMessage(&msg, NULL, 0, 0))
 	    {
    	      	// TranslateMessage is not called because AbiWord
 	      	// has its own way of decoding keyboard accelerators
@@ -1182,7 +1173,7 @@ try
 	    	
 			// Check for idle condition
 			while( !UT_Win32Idle::_isEmpty() &&
-                   !PeekMessage(&msg, NULL, 0, 0, PM_NOREMOVE) ) 
+                   !PeekMessageW(&msg, NULL, 0, 0, PM_NOREMOVE) ) 
 			{
 				// Fire idle functions when no pending messages
 		    	UT_Win32Idle::_fireall();
@@ -1323,18 +1314,8 @@ bool AP_Win32App::handleModelessDialogMessage( MSG * msg )
 		{
 			hWnd = (HWND) m_IdTable[ iCounter ].pDialog->pGetWindowHandle();
 
-			if(!m_bForceAnsi && UT_IsWinNT())
-			{
-				// Since the message was fetched with GetMessageW,
-				// it must be processed with Unicode functions
-				if( hWnd && IsDialogMessageW( hWnd, msg ) )
-					return true;
-			}
-			else
-			{
-				if( hWnd && IsDialogMessage( hWnd, msg ) )
-					return true;
-			}
+			if( hWnd && IsDialogMessageW( hWnd, msg ) )
+				return true;
 		}
 		else
 			break;
@@ -1347,9 +1328,11 @@ bool AP_Win32App::handleModelessDialogMessage( MSG * msg )
 void AP_Win32App::errorMsgBadArg(const char *msg)
 {
 	char *pszMessage;
+	UT_Win32LocaleString str;
 
 	pszMessage = g_strdup_printf ("%s\nRun with --help' to see a full list of available command line options.\n", msg);
-	MessageBox(NULL, pszMessage, "Command Line Option Error", MB_OK|MB_ICONERROR);
+	str.fromUTF8(pszMessage);
+	MessageBoxW(NULL, str.c_str(), L"Command Line Option Error", MB_OK|MB_ICONERROR);
 	g_free( pszMessage );
 }
 
@@ -1407,8 +1390,11 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args, bool & bSuccess)
 			UT_String s = "AbiWord: ";
 			s+= Args->m_sFiles[0];
 			
-			GR_Graphics * pG = GR_Win32Graphics::getPrinterGraphics(Args->m_sPrintTo, s.c_str());
-			if(!pG)
+            UT_Win32LocaleString prn, doc;
+			prn.fromASCII (Args->m_sPrintTo);
+			doc.fromASCII (s.c_str());
+			GR_Graphics * pG = GR_Win32Graphics::getPrinterGraphics(prn.c_str(), doc.c_str());			
+            if(!pG)
 			{
 				// do not assert here, if the graphics creation failed, the static
 				// constructor has asserted already somewhere more relevant
@@ -1492,9 +1478,9 @@ bool AP_Win32App::doWindowlessArgs(const AP_Args *Args, bool & bSuccess)
 */	
 UT_Vector*	AP_Win32App::getInstalledUILanguages(void)
 {		
-	UT_Vector* pVec = new UT_Vector();
-	UT_Language lang;	
-					
+	UT_Vector* pVec = new UT_Vector(64,16);
+	UT_Language lang;
+
 	for (UT_uint32 i=0; i< lang.getCount(); i++)
 	{
 		const char *pLangCode = (const char*)lang.getNthLangCode(i);
@@ -1517,49 +1503,49 @@ UT_Vector*	AP_Win32App::getInstalledUILanguages(void)
 */
 bool	AP_Win32App::doesStringSetExist(const char* pLocale)
 {
-	FILE* in;
-	const char * szDirectory = NULL;	
+	HANDLE in;
+	const char * szDirectory = NULL;
 
 	UT_return_val_if_fail(pLocale, false);
 	
 	getPrefsValueDirectory(true,AP_PREF_KEY_StringSetDirectory,&szDirectory);
 	UT_return_val_if_fail(((szDirectory) && (*szDirectory)), false);
 
-	char * szPathname = (char *)UT_calloc(sizeof(char),strlen(szDirectory)+strlen(pLocale)+100);
+	char *szPathname = (char*) UT_calloc(sizeof(char),strlen(szDirectory)+strlen(pLocale)+100);
 	UT_return_val_if_fail(szPathname, false);
-				
-	sprintf(szPathname,"%s%s%s.strings",
-				szDirectory,
-				((szDirectory[strlen(szDirectory)-1]=='\\') ? "" : "\\"),
-				pLocale);				
 	
-	in =  fopen(szPathname, "r");	
+	char *szDest = szPathname;
+	strcpy(szDest, szDirectory);
+	szDest += strlen(szDest);
+	if ((szDest > szPathname) && (szDest[-1]!='\\'))
+		*szDest++='\\';
+	lstrcpyA(szDest,pLocale);
+	lstrcatA(szDest,".strings");
+
+	UT_Win32LocaleString wsFilename;
+	wsFilename.fromUTF8(szPathname);
+
+	in = CreateFileW(wsFilename.c_str(),0,FILE_SHARE_READ|FILE_SHARE_WRITE,NULL,
+		OPEN_EXISTING,0,NULL);
 	g_free (szPathname);
 	
-	if (in)
+	if (in!=INVALID_HANDLE_VALUE)
 	{
-		fclose(in);		
+		CloseHandle(in);
 		return true;
 	}			
 	
 	return false;
 }
 
-/* From UCS4 To WinLocale */
-UT_String  	AP_Win32App::s_fromUCS4ToWinLocale(const UT_UCS4Char * szIn)
-{		
-	UT_UCS4String sUCS4(szIn);
-	UT_String sRslt;
-	
-	char *pText = UT_convert ((char *)sUCS4.ucs4_str(),
-							  sUCS4.length()*sizeof(UT_UCS4Char),
-							  ucs4Internal(),
-							  XAP_App::getApp()->getDefaultEncoding(),
-							  NULL, NULL);
-	sRslt = pText;
-	g_free(pText);
-	return sRslt;
 
+/* From UCS4 To WinLocale */
+UT_Win32LocaleString	AP_Win32App::s_fromUCS4ToWinLocale(const UT_UCS4Char * szIn)
+{	
+	UT_Win32LocaleString sRslt;
+	sRslt.fromUCS4(szIn);
+	//UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+	return sRslt;
 }
 
 /* From WinLocale To UCS4*/
@@ -1574,7 +1560,7 @@ UT_UCS4String	AP_Win32App::s_fromWinLocaleToUCS4(const char* szIn)
 }
 
 /* From  UTF8 To WinLocale */
-UT_String 		AP_Win32App::s_fromUTF8ToWinLocale(const char* szInUTF8)
+UT_Win32LocaleString 	AP_Win32App::s_fromUTF8ToWinLocale(const char* szInUTF8)
 {
 	UT_UTF8String utf8(szInUTF8);	
 	UT_UCS4String sUCS4(utf8.ucs4_str());
