@@ -533,10 +533,10 @@ void  AP_Dialog_Lists::fillUncustomizedValues(void)
 	// if we can get the current font, we will use it where appropriate
 	// the "NULL" string does not work too well on Windows in numbered lists
 	const gchar** props_in = NULL;
-	const gchar * font_family;
+	const gchar * font_family = NULL;
 	if (getView()->getCharFormat(&props_in))
 		font_family = UT_getAttribute("font-family", props_in);
-	else
+	if (!font_family)
 		font_family =(const gchar *) "NULL";
 
 	if(m_NewListType == NOT_A_LIST)
@@ -705,7 +705,6 @@ void  AP_Dialog_Lists::generateFakeLabels(void)
 	{
 		DELETEP(m_pFakeLayout[i]);
 		m_pFakeSdh[i] = static_cast<PL_StruxDocHandle>(new pf_Frag_Strux_Block(NULL,0));
-		static_cast<const pf_Frag *>(m_pFakeSdh[i])->setPos(i);
 		m_pFakeLayout[i] = new fl_Layout((PTStruxType) 0 , (PL_StruxDocHandle) m_pFakeSdh[i] );
 	}
 	//
@@ -1186,8 +1185,9 @@ void AP_Lists_preview::setData(const gchar * pszFont,float fAlign,float fIndent)
 }
 
 
-void AP_Lists_preview::draw(void)
+void AP_Lists_preview::draw(const UT_Rect *clip)
 {
+	UT_UNUSED(clip);
 	UT_return_if_fail(m_pFont);
 
 	GR_Painter painter(m_gc);
