@@ -212,9 +212,10 @@ BeginLayout(Main,0)
 		MenuItem(AP_MENU_ID_TABLE_FORMAT)
 		MenuItem(AP_MENU_ID_FMT_FRAME)
 		MenuItem(AP_MENU_ID_FMT_IMAGE)
-#if 0 // someone code and turn this back on
+// #if 0 // someone code and turn this back on
+//	Maleesh 6/10/2010 -  
 		MenuItem(AP_MENU_ID_FMT_BORDERS)
-#endif
+// #endif
 		Separator()
 		MenuItem(AP_MENU_ID_FMT_COLUMNS)
 #if !XAP_SIMPLE_MENU	
@@ -323,7 +324,9 @@ BeginLayout(Main,0)
 
 #if !XAP_SIMPLE_MENU
 		MenuItem(AP_MENU_ID_TOOLS_PLUGINS)
+#ifndef TOOLKIT_WIN
 		MenuItem(AP_MENU_ID_TOOLS_SCRIPTS)
+#endif
 		MenuItem(AP_MENU_ID_TOOLS_MAILMERGE)
 #if XAP_PREFSMENU_UNDER_TOOLS
 		Separator()
