@@ -45,14 +45,14 @@ dcl(MSG_IE_NoMemory,			"Out of memory attempting to open %s")
 dcl(MSG_IE_UnknownType, 		"File %s is of unknown type")
 dcl(MSG_IE_FakeType,			"File %s is not of the type it claims to be")
 dcl(MSG_IE_UnsupportedType, 	"File %s is not of a currently supported file type")
-dcl(MSG_IE_BogusDocument,		"AbiWord cannot open %s. It appears to be an invalid document")
+dcl(MSG_IE_BogusDocument,		"AbiWord cannot open %s. It appears to be an invalid document.")
 dcl(MSG_IE_CouldNotOpen,		"Could not open file %s for writing")
 dcl(MSG_IE_CouldNotWrite,		"Could not write to file %s")
 dcl(MSG_SpellSelectionDone,		"AbiWord finished checking the selection.")
 dcl(MSG_SpellDone,				"The spelling check is complete.")
 dcl(MSG_PrintStatus,			"Printing page %d of %d")
 dcl(MSG_RevertFile, "Revert file to last saved state?")
-dcl(MSG_PrintingDoc, "Printing Document..")
+dcl(MSG_PrintingDoc, "Printing Document...")
 dcl(MSG_NoBreakInsideTable, "Can not insert a Break inside a table")
 dcl(MSG_NoBreakInsideFrame, "Can not insert a Break inside a text box")
 dcl(MSG_AutoRevisionOffWarning, "Are you sure you do not want to maintain full history record? If you proceed, you will not be able to restore earlier versions of this document.")
@@ -547,6 +547,17 @@ dcl(DLG_FormatTable_SetImage,            "Set Image")
 dcl(DLG_FormatTable_SelectImage,         "Select image from File")
 dcl(DLG_FormatTable_NoImageBackground,   "Set no image")
 
+dcl(DLG_BorderShading_Title,				"Borders and Shading")
+dcl(DLG_BorderShading_Borders,	   			"Borders")
+dcl(DLG_BorderShading_Shading,    			"Shading")
+dcl(DLG_BorderShading_Use_Shading, 			"Enable shading")
+dcl(DLG_BorderShading_Border_Color,   		"Border color:")
+dcl(DLG_BorderShading_Shading_Color,		"Shading color:")
+dcl(DLG_BorderShading_Color,		        "Color:")
+dcl(DLG_BorderShading_Thickness,	        "Thickness:")
+dcl(DLG_BorderShading_Border_Style,	        "Style:")
+dcl(DLG_BorderShading_Offset,				"Offset:")
+dcl(DLG_BorderShading_Preview,	   			"Preview")
 
 dcl(DLG_Field_FieldTitle,				"Insert field")
 dcl(DLG_Field_FieldTitle_Capital,			"Insert Field")
@@ -956,9 +967,9 @@ dcl(MENU_LABEL_FMT_PARAGRAPH,"&Paragraph")
 dcl(MENU_LABEL_FMT_BULLETS,"Bullets and &Numbering")
 dcl(MENU_LABEL_TABLE_FORMAT, "&Table")
 dcl(MENU_LABEL_FMT_DOCUMENT,"&Document")
-dcl(MENU_LABEL_FMT_BORDERS,"Borders and Shading")
-dcl(MENU_LABEL_FMT_HDRFTR,"Header/Footers")
-dcl(MENU_LABEL_FMT_FOOTNOTES,"Footnotes and Endnotes")
+dcl(MENU_LABEL_FMT_BORDERS,"&Borders and Shading")
+dcl(MENU_LABEL_FMT_HDRFTR,"&Header/Footers")
+dcl(MENU_LABEL_FMT_FOOTNOTES,"Footnotes and &Endnotes")
 dcl(MENU_LABEL_FMT_TABLEOFCONTENTS,"Table of Contents")
 dcl(MENU_LABEL_FMT_COLUMNS,"&Columns")
 dcl(MENU_LABEL_FMT_TOGGLECASE,"C&hange Case")
@@ -974,8 +985,8 @@ dcl(MENU_LABEL_FMT_ITALIC,"&Italic")
 dcl(MENU_LABEL_FMT_UNDERLINE,"&Underline")
 dcl(MENU_LABEL_FMT_OVERLINE,"&Overline")
 dcl(MENU_LABEL_FMT_STRIKE,"Stri&ke")
-dcl(MENU_LABEL_FMT_TOPLINE,"Topline")
-dcl(MENU_LABEL_FMT_BOTTOMLINE,"Bottomline")
+dcl(MENU_LABEL_FMT_TOPLINE,"To&pline")
+dcl(MENU_LABEL_FMT_BOTTOMLINE,"Bo&ttomline")
 dcl(MENU_LABEL_FMT_SUPERSCRIPT,"Supe&rscript")
 dcl(MENU_LABEL_FMT_SUBSCRIPT,"&Subscript")
 dcl(MENU_LABEL_FMT_FRAME,"Text Box")
@@ -988,7 +999,7 @@ dcl(MENU_LABEL_FMT_DIRECTION_SD_RTL, "RTL &Section")
 dcl(MENU_LABEL_FMT_DIRECTION_DD_RTL, "RTL &Paragraph")
 dcl(MENU_LABEL_FMT_DIRECTION_DO_LTR, "&Left-to-right text")
 dcl(MENU_LABEL_FMT_DIRECTION_DO_RTL, "&Right-to-left text")
-dcl(MENU_LABEL_FMT_EMBED, "Format Object")
+dcl(MENU_LABEL_FMT_EMBED, "Format Ob&ject")
 dcl(MENU_LABEL_TOOLS,"&Tools")
 dcl(MENU_LABEL_TOOLS_SPELLING,"&Spelling")
 dcl(MENU_LABEL_TOOLS_SPELL,"Check &Spelling")
@@ -1177,7 +1188,7 @@ dcl(MENU_STATUSLINE_EDIT_SELECT_FRAME,"Select the Text Box")
 dcl(MENU_STATUSLINE_EDIT_CUTEMBED,"Cut Embedded Object")
 dcl(MENU_STATUSLINE_EDIT_COPYEMBED,"Copy Embedded Object")
 dcl(MENU_STATUSLINE_EDIT_DELETEEMBED,"Delete Embedded Object")
-dcl(MENU_STATUSLINE_EDIT_LATEXEQUATION,"Edit Latex Equation")
+dcl(MENU_STATUSLINE_EDIT_LATEXEQUATION,"Edit LaTeX Equation")
 dcl(MENU_STATUSLINE_VIEW," ")
 dcl(MENU_STATUSLINE_VIEW_NORMAL,"Normal View")
 dcl(MENU_STATUSLINE_VIEW_WEB,"Web Layout")
