@@ -736,8 +736,10 @@ bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 				UT_return_val_if_fail(field, false);
 
 				m_pie->populateFields ();
-				if(field->getValue() != NULL)
-					m_pie->write(field->getValue());
+				if(field->getValue() != NULL) {
+					UT_UCS4String ws(field->getValue());
+					_outputData(ws.ucs4_str(),ws.length());
+				}
 
 				return true;
 			
@@ -755,6 +757,9 @@ bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 
 			case PTO_Annotation:
 				return true;
+                
+			case PTO_RDFAnchor:
+				return true;
 
 			default:
 				UT_ASSERT_HARMLESS(UT_TODO);
