@@ -11,6 +11,7 @@ _rtf_keyword rtfKeywords[] = {
 	{"abibotline", false, false, NO_CONTEXT, RTF_KW_abibotline }, 
 	{"abicellprops", false, false, NO_CONTEXT, RTF_KW_abicellprops }, 
 	{"abiembed", false, false, NO_CONTEXT, RTF_KW_abiembed }, 
+	{"abiembeddata", false, false, NO_CONTEXT, RTF_KW_abiembeddata }, 
 	{"abiendcell", false, false, NO_CONTEXT, RTF_KW_abiendcell }, 
 	{"abiendtable", false, false, NO_CONTEXT, RTF_KW_abiendtable }, 
 	{"abifieldD", false, false, NO_CONTEXT, RTF_KW_abifieldD }, 
@@ -990,6 +991,8 @@ _rtf_keyword rtfKeywords[] = {
 	{"rawclbghoriz", false, false, NO_CONTEXT, RTF_KW_rawclbghoriz }, /* 2002 */ 
 	{"rawclbgvert", false, false, NO_CONTEXT, RTF_KW_rawclbgvert }, /* 2002 */ 
 	{"rdblquote", false, false, NO_CONTEXT, RTF_KW_rdblquote }, 
+	{"rdfanchorstart", false, false, NO_CONTEXT, RTF_KW_rdfanchorstart }, 
+	{"rdfanchorend", false, false, NO_CONTEXT, RTF_KW_rdfanchorend }, 
 	{"red", false, false, NO_CONTEXT, RTF_KW_red }, 
 	{"rempersonalinfo", false, false, NO_CONTEXT, RTF_KW_rempersonalinfo }, /* 2002 */ 
 	{"result", false, false, NO_CONTEXT, RTF_KW_result }, 
