@@ -37,12 +37,15 @@
 #endif
 
 #include "pd_Document.h"
+#include "pd_DocumentRDF.h"
 
 #include "ap_Prefs.h"
 
 #include "ie_imp_XML.h"
 #include "ie_types.h"
 
+#define DEBUG_RDF_IO  1
+
 /*****************************************************************/
 /*****************************************************************/
 
@@ -250,6 +253,7 @@ void IE_Imp_XML::charData(const gchar *s, int len)
 		case _PS_Block:
 		case _PS_IgnoredWordsItem:
 		case _PS_Meta:
+		case _PS_RDFTriple:
 		case _PS_Revision:
 			{
 				UT_UCS4String buf(s,static_cast<size_t>(len),!m_bWhiteSignificant);
@@ -261,20 +265,34 @@ void IE_Imp_XML::charData(const gchar *s, int len)
 				switch (m_parseState)
 					{
 					case _PS_Block:
-						if (!m_bWhiteSignificant && m_bStripLeading && (buf[0] == UCS_SPACE))
 						{
-							if (buf.size () > 1)
+						unsigned int s = 0, t = 0;
+						UT_UCS4Char *pbuf = (UT_UCS4Char*) buf.ucs4_str();
+						int newlen = buf.size();
+						while (s < newlen) {
+							if (pbuf[s]!=10 && pbuf[s]!=13) {
+								if (s > t) pbuf[t] = pbuf[s];
+								t++;
+							}
+							s++;
+						}
+						newlen = t;
+
+						if (!m_bWhiteSignificant && m_bStripLeading && (pbuf[0] == UCS_SPACE))
+						{
+							if (newlen > 1)
 							{
-								X_CheckError(appendSpan (buf.ucs4_str()+1, buf.size()-1));
-								m_iCharCount += buf.size () - 1;
+								X_CheckError(appendSpan (pbuf+1, newlen-1));
+								m_iCharCount += newlen - 1;
 							}
 						}
 						else
 						{
-							X_CheckError(appendSpan (buf.ucs4_str(), buf.size()));
-							m_iCharCount += buf.size ();
+							X_CheckError(appendSpan (pbuf, newlen));
+							m_iCharCount += newlen;
+						}
+						m_bStripLeading = (pbuf[newlen-1] == UCS_SPACE);
 						}
-						m_bStripLeading = (buf[buf.size()-1] == UCS_SPACE);
 						return;
 					case _PS_IgnoredWordsItem:
 						return;
@@ -284,6 +302,40 @@ void IE_Imp_XML::charData(const gchar *s, int len)
 							getDoc()->setMetaDataProp(m_currentMetaDataName, data);
 							return;
 						}
+					case _PS_RDFTriple:
+                    {
+                        std::string data(s,len);
+
+                        if(!m_rdfMutation)
+                        {
+                            UT_DEBUGMSG(("ie_imp_XML should be parsing triple, but we are not in right parse state!\n"));
+                            return;
+                        }
+
+#ifdef DEBUG_RDF_IO                        
+                        UT_DEBUGMSG(("xml::import() adding s:%s p:%s o:%s otv:%d ots:%s\n",
+                                     m_rdfSubject.c_str(),
+                                     m_rdfPredicate.c_str(),
+                                     data.c_str(),
+                                     m_rdfObjectType,
+                                     m_rdfXSDType.c_str()
+                            ));
+                        {
+                            static int addCount = 0;
+                            addCount++;
+                            UT_DEBUGMSG(("xml::import() addCount:%d\n", addCount ));
+                        }
+#endif
+                        
+                        m_rdfMutation->add(
+                            m_rdfSubject,
+                            m_rdfPredicate,
+                            PD_Object( data,
+                                       m_rdfObjectType,
+                                       m_rdfXSDType ));
+
+                        return;
+                    }
 					case _PS_Revision:
 
 						// 0 is not a valid revision Id
@@ -381,7 +433,6 @@ void IE_Imp_XML::charData(const gchar *s, int len)
 			}
 			
 		default:
-			UT_DEBUGMSG(("ie_imp_XML::charData Default just return \n"));
 			return;
 		}
 }
